﻿using System;

using Microsoft.BizTalk.Operations;

namespace BizTalkFactory.Management.Automation
{
    public class BtsMessage : BtsArtifact
    {
        private BizTalkMessage message_;

        private BtsMessage(BtsCatalog catalog, BizTalkMessage message)
            : base(catalog)
        {
            message_ = message;
        }

        public static BtsMessage FromItem(BtsCatalog catalog, object item)
        {
            return new BtsMessage(catalog, item as BizTalkMessage);
        }

        #region Attributes

        public override string Name
        {
            get { return message_.MessageID.ToString("D"); }
        }

        public string AdapterName
        {
            get { return message_.AdapterName; }
        }

        public DateTime CreationTime
        {
            get { return message_.CreationTime; }
        }

        public string ErrorCode
        {
            get { return message_.ErrorCode; }
        }

        public string ErrorDescription
        {
            get { return message_.ErrorDescription; }
        }

        public string HostName
        {
            get { return message_.HostName; }
        }

        public Guid Identifier
        {
            get { return message_.MessageID; }
        }

        public Guid InstanceID
        {
            get { return message_.InstanceID; }
        }

        public BtsInstanceStatus InstanceStatus
        {
            get { return InstanceStatusConverter.FromNativeType(message_.InstanceStatus); }
        }

        public BtsMessageStatus MessageStatus
        {
            get { return MessageStatusConverter.FromNativeType(message_.MessageStatus); }
        }

        public string MessageType
        {
            get { return message_.MessageType; }
        }

        public BtsServiceClass ServiceClass
        {
            get { return ServiceClassConverter.FromNativeType(message_.Class); }
        }

        public string ServiceType
        {
            get { return message_.ServiceType; }
        }

        #endregion

        #region Operations

        public void SaveToFile(string path)
        {
        }

        #endregion
    }
}
