﻿using System;

using Microsoft.BizTalk.Operations;

namespace BizTalkFactory.Management.Automation
{
    public class BtsServiceInstance : BtsArtifact
    {
        private Instance instance_;

        private BtsServiceInstance(BtsCatalog catalog, Instance instance)
            : base(catalog)
        {
            instance_ = instance;
        }

        public static BtsServiceInstance FromItem(BtsCatalog catalog, object item)
        {
            return new BtsServiceInstance(catalog, item as Instance);
        }

        #region Attributes

        public override string Name
        {
            get { return Identifier.ToString("D"); }
        }

        public string Application
        {
            get {
                if (instance_ is MessageBoxServiceInstance)
                    return (instance_ as MessageBoxServiceInstance).Application;
                else
                    return String.Empty;
            }
        }

        public DateTime CreationTime
        {
            get { return instance_.CreationTime; }
        }

        public int ErrorCategory
        {
            get {
                if (instance_ is MessageBoxServiceInstance)
                    return (instance_ as MessageBoxServiceInstance).ErrorCategory;
                else
                    return 0;
            }
        }

        public string ErrorCode
        {
            get
            {
                if (instance_ is MessageBoxServiceInstance)
                    return (instance_ as MessageBoxServiceInstance).ErrorCode;
                else
                    return String.Empty;
            }
        }

        public string ErrorDescription
        {
            get { return instance_.ErrorDescription; }
        }

        public string HostName
        {
            get { return instance_.HostName; }
        }

        public Guid Identifier
        {
            get { return instance_.ID; }
        }

        public BtsInstanceStatus InstanceStatus
        {
            get { return InstanceStatusConverter.FromNativeType(instance_.InstanceStatus); }
        }

        public BtsPendingOperationType PendingOperation
        {
            get
            {
                if (instance_ is MessageBoxServiceInstance)
                    return PendingOperationTypeConverter.FromNativeType((instance_ as MessageBoxServiceInstance).PendingOperation);
                else
                    return BtsPendingOperationType.NoOperation;
            }
        }

        public BtsServiceClass ServiceClass
        {
            get { return ServiceClassConverter.FromNativeType(instance_.Class); }
        }

        public string ServiceType
        {
            get { return instance_.ServiceType; }
        }

        #endregion

        #region Operations

        public void Resume()
        {
            BizTalkOperations operations = new BizTalkOperations(Catalog.Instance, Catalog.Database);
            operations.ResumeInstance(Identifier);
        }

        public void Suspend()
        {
            BizTalkOperations operations = new BizTalkOperations(Catalog.Instance, Catalog.Database);
            operations.SuspendInstance(Identifier);
        }

        public void Terminate()
        {
            BizTalkOperations operations = new BizTalkOperations(Catalog.Instance, Catalog.Database);
            operations.TerminateInstance(Identifier);
        }

        #endregion
    }
}
