using System;
using System.Configuration;
using System.IO;

using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.Management.Automation.UnitTests
{
    public sealed class BizTalkParams
    {
        private static volatile BizTalkParams instance_;
        private static object syncRoot = new Object();

        private BtsCatalog catalog_ = null;
        private string database_;
        private string server_;
        
        private BizTalkParams()
        {
            database_ = ConfigurationManager.AppSettings["BizTalkMgmtDb"];
            server_ = ConfigurationManager.AppSettings["BizTalkMgmtServer"];
        }

        public static string Database
        {
            get { return Instance.database_; }
        }

        public static string Server
        {
            get { return Instance.server_; }
        }

        public static BizTalkParams Instance
        {
            get
            {
                if (instance_ == null)
                {
                    lock (syncRoot)
                    {
                        if (instance_ == null)
                            instance_ = new BizTalkParams();
                    }
                }

                return instance_;
            }
        }

        public BtsCatalog Catalog
        {
            get { return catalog_; }
        }

        #region Helpers

        public static BtsCatalog Connect()
        {
            return BtsCatalog.Connect(BizTalkParams.Server, BizTalkParams.Database);
        }

        public static string GetUniqueName(string prefix)
        {
            return prefix + Guid.NewGuid().ToString("d").Replace("-", "");
        }

        public static string ExtractResource(string name)
        {
            string assembly = Path.GetFileNameWithoutExtension(System.Reflection.Assembly.GetExecutingAssembly().Location);
            string resource = String.Format("{0}.res.{1}", assembly, name);

            string path = Path.Combine(Path.GetTempPath(), resource);

            ExtractResourceFile(resource, path);

            return path;
        }

        private static void ExtractResourceFile(string resource, string path)
        {
            using (Stream inputStream = System.Reflection.Assembly.GetExecutingAssembly().GetManifestResourceStream(resource))
            using (Stream outputStream = new FileStream(path, FileMode.OpenOrCreate, FileAccess.Write))
            using (BinaryReader reader = new BinaryReader(inputStream))
            using (BinaryWriter writer = new BinaryWriter(outputStream))
            {
                int count = 0;
                byte[] bytes = new byte[4096];
                while ((count = reader.Read(bytes, 0, bytes.Length)) > 0)
                    writer.Write(bytes, 0, count);
            }
        }

        public static void SafeDeleteFile(string path)
        {
            try
            {
                if (!String.IsNullOrEmpty(path) && File.Exists(path))
                    File.Delete(path);
            }
            catch (System.Exception /* e */)
            {
                // prevents the unit testing framework from reporting a test failure
            }
        }

        #endregion
    }
}