using System;
using System.IO;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace BizTalkFactory.Management.Automation.UnitTests
{
    [TestClass]
    public class AddResourceTestClass
    {
        private static string name = BizTalkParams.GetUniqueName("A");

        [ClassInitialize]
        public static void Setup(TestContext context)
        {
            BtsCatalog catalog = BizTalkParams.Connect();
            BtsApplication application = catalog.AddNewApplication(name);
        }

        [ClassCleanup]
        public static void TearDown()
        {
            BtsCatalog catalog = BizTalkParams.Connect();
            try { catalog.RemoveApplication(name, true); }
            catch { }
        }

        [TestMethod]
        public void AddQuickFileResourceTest()
        {
            string path = BizTalkParams.ExtractResource("System.BizTalk_File");
            string new_path = Path.Combine(Path.GetDirectoryName(path), "~" + Path.GetFileName(path));
            System.IO.File.Move(path, new_path);

            BtsCatalog catalog = BizTalkParams.Connect();
            BtsApplication application = catalog.Applications[name];
            BtsResource resource = application.AddNewResource(new_path);

            Assert.AreEqual("System.BizTalk:File", resource.ResourceType);
        }

        [TestMethod]
        public void AddFileResourceTest()
        {
            string path = BizTalkParams.ExtractResource("System.BizTalk_File");

            BtsCatalog catalog = BizTalkParams.Connect();
            BtsApplication application = catalog.Applications[name];
            BtsResource resource = application.AddNewResource(path, "System.BizTalk:File", false);

            Assert.AreEqual("System.BizTalk:File", resource.ResourceType);
        }

        [TestMethod]
        public void AddQuickAssemblyResourceTest()
        {
            string path = System.Reflection.Assembly.GetExecutingAssembly().Location;
            string new_path = Path.Combine(Path.GetDirectoryName(path), "~" + Path.GetFileName(path));
            System.IO.File.Move(path, new_path);

            BtsCatalog catalog = BizTalkParams.Connect();

            BtsApplication application = catalog.Applications[name];
            BtsResource resource = application.AddNewResource(new_path);

            Assert.AreEqual("System.BizTalk:Assembly", resource.ResourceType);
        }


        [TestMethod]
        public void AddAssemblyResourceTest()
        {
            string path = System.Reflection.Assembly.GetExecutingAssembly().Location;

            BtsCatalog catalog = BizTalkParams.Connect();

            BtsApplication application = catalog.Applications[name];
            BtsResource resource = application.AddNewResource(path, "System.BizTalk:Assembly", false);

            Assert.AreEqual("System.BizTalk:Assembly", resource.ResourceType);
        }

        [TestMethod]
        public void AddQuickBizTalkAssemblyResourceTest()
        {
            string path = path = BizTalkParams.ExtractResource("BizTalkFactory.UnitTest.Application.dll");
            string new_path = Path.Combine(Path.GetDirectoryName(path), "~" + Path.GetFileName(path));
            System.IO.File.Move(path, new_path);

            BtsCatalog catalog = BizTalkParams.Connect();
            BtsApplication application = catalog.Applications[name];
            BtsResource resource = application.AddNewResource(new_path);

            Assert.AreEqual("System.BizTalk:BizTalkAssembly", resource.ResourceType);
        }

        [TestMethod]
        public void AddBizTalkAssemblyResourceTest()
        {
            string path = path = BizTalkParams.ExtractResource("BizTalkFactory.UnitTest.Application.dll");

            BtsCatalog catalog = BizTalkParams.Connect();
            BtsApplication application = catalog.Applications[name];
            BtsResource resource = application.AddNewResource(path, "System.BizTalk:BizTalkAssembly", false);

            Assert.AreEqual("System.BizTalk:BizTalkAssembly", resource.ResourceType);
        }

        [TestMethod]
        public void AddQuickComResourceTest()
        {
            string path = System.IO.Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.System), "zipfldr.dll");
            string new_path = Path.Combine(Path.GetDirectoryName(path), "~" + Path.GetFileName(path));
            System.IO.File.Move(path, new_path);

            BtsCatalog catalog = BizTalkParams.Connect();

            BtsApplication application = catalog.Applications[name];
            BtsResource resource = application.AddNewResource(new_path);

            Assert.AreEqual("System.BizTalk:Com", resource.ResourceType);
        }

        [TestMethod]
        public void AddComResourceTest()
        {
            string path = System.IO.Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.System), "zipfldr.dll");

            BtsCatalog catalog = BizTalkParams.Connect();

            BtsApplication application = catalog.Applications[name];
            BtsResource resource = application.AddNewResource(path, "System.BizTalk:Com", false);

            Assert.AreEqual("System.BizTalk:Com", resource.ResourceType);
        }
    }
 }
