﻿using System;
using System.Net;

using Microsoft.BizTalk.Management;

namespace BizTalkFactory.Management.Automation
{
    public class BtsAdapter : BtsArtifact 
    {
        private AdapterSetting adapterSetting_;

        private BtsAdapter(BtsCatalog catalog, AdapterSetting protocolType)
            : base(catalog)
        {
            adapterSetting_ = protocolType;
        }

        public static BtsAdapter FromItem(BtsCatalog catalog, object item)
        {
            return new BtsAdapter(catalog, item as AdapterSetting);
        }

        #region Attributes

        public override string Name
        {
            get { return adapterSetting_.Name; }
        }

        public string Description
        {
            get { return adapterSetting_.Comment; }
        }

        public string DefaultInboundConfig
        {
            get { return adapterSetting_.DefaultInboundCfg; }
        }

        public string DefaultOutboundConfig
        {
            get { return adapterSetting_.DefaultOutboundCfg; }
        }

        #endregion

        #region Operations

        public BtsReceiveHandler AddNewReceiveHandler(BtsHost host)
        {
            try
            {
                ReceiveHandler.StaticScope = ManagementScopeHelper.GetScope(typeof(ReceiveHandler), Catalog.Instance, Catalog.Database);
                ReceiveHandler handler = ReceiveHandler.CreateInstance();

                handler.AutoCommit = false;

                handler.LateBoundObject["AdapterName"] = Name;
                handler.LateBoundObject["HostName"] = host.Name;
                handler.LateBoundObject["CustomCfg"] = DefaultInboundConfig;

                handler.AutoCommit = true;
                handler.CommitObject();


                // retrieve object

                return BtsReceiveHandler.FromItem(Catalog, handler);
            }

            catch (System.Exception e)
                { throw new BtsException(e); }

            finally
            {
                ReceiveHandler.StaticScope = null;
            }
        }

        public BtsSendHandler AddNewSendHandler(BtsHost host, string OutboundConfig)
        {
            try
            {
                SendHandler2.StaticScope = ManagementScopeHelper.GetScope(typeof(SendHandler2), Catalog.Instance, Catalog.Database);
                SendHandler2 handler = SendHandler2.CreateInstance();

                handler.AutoCommit = false;

                handler.LateBoundObject["AdapterName"] = Name;
                handler.LateBoundObject["HostName"] = host.Name;

                if (String.IsNullOrEmpty(OutboundConfig))
                    handler.LateBoundObject["CustomCfg"] = DefaultOutboundConfig;
                else
                    handler.LateBoundObject["CustomCfg"] = OutboundConfig;

                handler.AutoCommit = true;
                handler.CommitObject();

                // retrieve object

                return BtsSendHandler.FromItem(Catalog, handler);
            }

            catch (System.Exception e)
            { throw new BtsException(e); }

            finally
            {
                SendHandler2.StaticScope = null;
            }
        }

        #endregion
    }
}
