using System;

using Microsoft.BizTalk.ExplorerOM;

namespace BizTalkFactory.Management.Automation
{
    public abstract class BtsArtifact : IEquatable<BtsArtifact>
    {
        protected BtsCatalog catalog_;

        protected BtsArtifact(BtsCatalog catalog)
        {
            catalog_ = catalog;
        }

        public BtsCatalog Catalog
        {
            get { return catalog_; }
        }

        protected BtsCatalogExplorer BtsCatalogExplorer
        {
            get { return catalog_.BtsCatalogExplorer; }
        }

        public abstract string Name { get; }

        #region IEquatable<BtsArtifact> Members

        public bool Equals(BtsArtifact other)
        {
            if (ReferenceEquals(null, other)) return false;
            return (Name.Equals(other.Name));
        }

        #endregion

        #region Equality Implementation

        public override bool Equals(object obj)
        {
            return Equals(obj as BtsArtifact);
        }

        public override int GetHashCode()
        {
            return Name.GetHashCode();
        }

        public static bool operator ==(BtsArtifact left, BtsArtifact right)
        {
            if (ReferenceEquals(null, left)) return ReferenceEquals(null, right);
            return left.Equals(right);
        }

        public static bool operator !=(BtsArtifact left, BtsArtifact right)
        {
            return !(left == right);
        }

        #endregion
    }
}