using System;
using System.Collections.Generic;
using System.Xml;

using Microsoft.BizTalk.ExplorerOM;
using Microsoft.BizTalk.Management;

namespace BizTalkFactory.Management.Automation
{
    public class BtsHost : BtsArtifact
    {
        private Host host_;
        private HostSetting setting_;

        private BtsHost(BtsCatalog catalog, Host host)
            : base(catalog)
        {
            host_ = host;

            RetrieveHostSetting(host.Name);
        }

        public static BtsHost FromItem(BtsCatalog catalog, object item)
        {
            try
            {
                return new BtsHost(catalog, item as Host);
            }
            catch (System.Exception e)
            { throw new BtsException(e); }
        }

        public bool AuthTrusted
        {
            get { return setting_.AuthTrusted; }
            set
            {
                try { setting_.AuthTrusted = value; }
                catch (System.Exception e)
                { throw new BtsException(e); }
            }
        }

        public bool Clustered
        {
            get { return !String.IsNullOrEmpty(setting_.ClusterResourceGroupName); }
        }

        public bool HostTracking
        {
            get { return setting_.HostTracking; }
            set
            {
                try { setting_.HostTracking = value; }
                catch (System.Exception e)
                { throw new BtsException(e); }
            }
        }

        public BtsHostType HostType
        {
            get { return HostTypeConverter.FromNativeType(host_.Type); }
        }

        public bool IsDefault
        {
            get { return setting_.IsDefault; }
            set
            {
                try { setting_.IsDefault = value; }
                catch (System.Exception e)
                { throw new BtsException(e); }
            }
        }

        public bool Is32BitOnly
        {
            get { return setting_.IsHost32BitOnly; }
            set
            {
                try { setting_.IsHost32BitOnly = value; }
                catch (System.Exception e)
                { throw new BtsException(e); }
            }
        }

        public override string Name
        {
            get { return setting_.Name; }
        }

        public string NtGroupName
        {
            get { return setting_.NTGroupName; }
        }

        #region Attributes

        public bool AllowMultipleResponses
        {
            get { return setting_.AllowMultipleResponses; }
            set
            {
                try { setting_.AllowMultipleResponses = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 DBQueueSizeThreshold
        {
            get { return setting_.DBQueueSizeThreshold; }
            set
            {
                try { setting_.DBQueueSizeThreshold = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 DBSessionThreshold
        {
            get { return setting_.DBSessionThreshold; }
            set
            {
                try { setting_.DBSessionThreshold = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public BtsDehydrationBehavior DehydrationBehavior
        {
            get { return DehydrationBehaviorConverter.FromManagementType(setting_.DehydrationBehavior); }
            set
            {
                try { setting_.DehydrationBehavior = DehydrationBehaviorConverter.ToManagementType(value); }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 DeliveryQueueSize
        {
            get { return setting_.DeliveryQueueSize; }
            set
            {
                try { setting_.DeliveryQueueSize = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 GlobalMemoryThreshold
        {
            get { return setting_.GlobalMemoryThreshold; }
            set
            {
                try { setting_.GlobalMemoryThreshold = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 InflightMessageThreshold
        {
            get { return setting_.InflightMessageThreshold; }
            set
            {
                try { setting_.InflightMessageThreshold = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public bool IsHost32BitOnly
        {
            get { return setting_.IsHost32BitOnly; }
            set
            {
                try { setting_.IsHost32BitOnly = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public bool LegacyWhitespace
        {
            get { return setting_.LegacyWhitespace; }
            set
            {
                try { setting_.LegacyWhitespace = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessageDeliveryMaximumDelay
        {
            get { return setting_.MessageDeliveryMaximumDelay; }
            set
            {
                try { setting_.MessageDeliveryMaximumDelay = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessageDeliveryOverdriveFactor
        {
            get { return setting_.MessageDeliveryOverdriveFactor; }
            set
            {
                try { setting_.MessageDeliveryOverdriveFactor = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessageDeliverySampleSpaceSize
        {
            get { return setting_.MessageDeliverySampleSpaceSize; }
            set
            {
                try { setting_.MessageDeliverySampleSpaceSize = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessageDeliverySampleSpaceWindow
        {
            get { return setting_.MessageDeliverySampleSpaceWindow; }
            set
            {
                try { setting_.MessageDeliverySampleSpaceWindow = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessagePublishMaximumDelay
        {
            get { return setting_.MessagePublishMaximumDelay; }
            set
            {
                try { setting_.MessagePublishMaximumDelay = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessagePublishOverdriveFactor
        {
            get { return setting_.MessagePublishOverdriveFactor; }
            set
            {
                try { setting_.MessagePublishOverdriveFactor = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessagePublishSampleSpaceSize
        {
            get { return setting_.MessagePublishSampleSpaceSize; }
            set
            {
                try { setting_.MessagePublishSampleSpaceSize = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessagePublishSampleSpaceWindow
        {
            get { return setting_.MessagePublishSampleSpaceWindow; }
            set
            {
                try { setting_.MessagePublishSampleSpaceWindow = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessagingMaxReceiveInterval
        {
            get { return setting_.MessagingMaxReceiveInterval; }
            set
            {
                try { setting_.MessagingMaxReceiveInterval = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 MessagingReqRespTTL
        {
            get { return setting_.MessagingReqRespTTL; }
            set
            {
                try { setting_.MessagingReqRespTTL = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }


        public Guid MsgAgentPerfCounterServiceClassID
        {
            get { return PerfCounterServiceClassConverter.FromManagementType(setting_.MsgAgentPerfCounterServiceClassID); }
            set
            {
                try { setting_.MsgAgentPerfCounterServiceClassID = PerfCounterServiceClassConverter.ToManagementType(value); }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ProcessMemoryThreshold
        {
            get { return setting_.ProcessMemoryThreshold; }
            set
            {
                try { setting_.ProcessMemoryThreshold = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 SubscriptionPauseAt
        {
            get { return setting_.SubscriptionPauseAt; }
            set
            {
                try { setting_.SubscriptionPauseAt = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 SubscriptionResumeAt
        {
            get { return setting_.SubscriptionResumeAt; }
            set
            {
                try { setting_.SubscriptionResumeAt = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThreadPoolSize
        {
            get { return setting_.ThreadPoolSize; }
            set
            {
                try { setting_.ThreadPoolSize = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThreadThreshold
        {
            get { return setting_.ThreadThreshold; }
            set
            {
                try { setting_.ThreadThreshold = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingBatchMemoryThresholdPercent
        {
            get { return setting_.ThrottlingBatchMemoryThresholdPercent; }
            set
            {
                try { setting_.ThrottlingBatchMemoryThresholdPercent = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }


        public UInt32 ThrottlingDeliveryOverride
        {
            get { return Convert.ToUInt32(setting_.ThrottlingDeliveryOverride); }
            set
            {
                try
                {
                    setting_.ThrottlingDeliveryOverride = (HostSetting.ThrottlingDeliveryOverrideValues)
                        Enum.Parse(typeof(HostSetting.ThrottlingDeliveryOverrideValues), value.ToString());
                }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingDeliveryOverrideSeverity
        {
            get { return setting_.ThrottlingDeliveryOverrideSeverity; }
            set
            {
                try { setting_.ThrottlingDeliveryOverrideSeverity = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingLimitToTriggerGC
        {
            get { return setting_.ThrottlingLimitToTriggerGC; }
            set
            {
                try { setting_.ThrottlingLimitToTriggerGC = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }


        public UInt32 ThrottlingPublishOverride
        {
            get { return Convert.ToUInt32(setting_.ThrottlingPublishOverride); }
            set
            {
                try
                {
                    setting_.ThrottlingPublishOverride = (HostSetting.ThrottlingPublishOverrideValues)
                        Enum.Parse(typeof(HostSetting.ThrottlingPublishOverrideValues), value.ToString());
                }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingPublishOverrideSeverity
        {
            get { return setting_.ThrottlingPublishOverrideSeverity; }
            set
            {
                try { setting_.ThrottlingPublishOverrideSeverity = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingSeverityDatabaseSize
        {
            get { return setting_.ThrottlingSeverityDatabaseSize; }
            set
            {
                try { setting_.ThrottlingSeverityDatabaseSize = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingSeverityInflightMessage
        {
            get { return setting_.ThrottlingSeverityInflightMessage; }
            set
            {
                try { setting_.ThrottlingSeverityInflightMessage = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingSeverityProcessMemory
        {
            get { return setting_.ThrottlingSeverityProcessMemory; }
            set
            {
                try { setting_.ThrottlingSeverityProcessMemory = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingSpoolMultiplier
        {
            get { return setting_.ThrottlingSpoolMultiplier; }
            set
            {
                try { setting_.ThrottlingSpoolMultiplier = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 ThrottlingTrackingDataMultiplier
        {
            get { return setting_.ThrottlingTrackingDataMultiplier; }
            set
            {
                try { setting_.ThrottlingTrackingDataMultiplier = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 TimeBasedMaxThreshold
        {
            get { return setting_.TimeBasedMaxThreshold; }
            set
            {
                try { setting_.TimeBasedMaxThreshold = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 TimeBasedMinThreshold
        {
            get { return setting_.TimeBasedMinThreshold; }
            set
            {
                try { setting_.TimeBasedMinThreshold = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public bool UseDefaultAppDomainForIsolatedAdapter
        {
            get { return setting_.UseDefaultAppDomainForIsolatedAdapter; }
            set
            {
                try { setting_.UseDefaultAppDomainForIsolatedAdapter = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        public UInt32 XlangMaxReceiveInterval
        {
            get { return setting_.XlangMaxReceiveInterval; }
            set
            {
                try { setting_.XlangMaxReceiveInterval = value; }
                catch (System.Exception e) { throw new BtsException(e); }
            }
        }

        #endregion

        #region Operations

        public void ExportHostSettings(string path)
        {
        }
#if BTS2010
        public void ImportHostSettings(string path)
        {
            SettingsWorker settingsWorker = new SettingsWorker(Catalog.Instance, Catalog.Database);
            HostSettings hostSettings = Helper.BtsSettingsHelper.ParseHostsSettings(path);
            
            ImportHostSettings(settingsWorker, hostSettings);

            RetrieveHostSetting(Name);
        }

        internal void ImportHostSettings(SettingsWorker settingsWorker, HostSettings settings)
        {
            ExportedSettings exportedSettings = new ExportedSettings();
            exportedSettings.ExportedGroup = String.Format("{0}:{1}", Catalog.Instance.ToUpper(), Catalog.Database.ToUpper());
            exportedSettings.HostSettings = settings;

            try {
                settingsWorker.ImportHostSettings(Name, Name, exportedSettings);
            }
            catch (Exception e)
            {
                throw new BtsException(settingsWorker.GetManagementExceptionDescription(e), e);
            }
        }
#endif
        #endregion

        #region Implementation

        private void RetrieveHostSetting(string hostName)
        {
            try
            {
                HostSetting.StaticScope = ManagementScopeHelper.GetScope(typeof(HostSetting), Catalog.Instance, Catalog.Database);
                foreach (HostSetting setting in HostSetting.GetInstances())
                    if (hostName == setting.Name)
                        setting_ = setting;
            }

            finally
            {
                HostSetting.StaticScope = null;
            }
        }

        #endregion
    }
}
