using System;

namespace BizTalkFactory.Management.Automation
{
    public class BtsOrchestration : BtsApplicationArtifact
    {
        private Microsoft.BizTalk.ExplorerOM.BtsOrchestration orchestration_;

        private BtsOrchestration(BtsApplication application, Microsoft.BizTalk.ExplorerOM.BtsOrchestration orchestration)
            : base(application)
        {
            orchestration_ = orchestration;
        }

        public static BtsOrchestration FromItem(BtsCatalog catalog, object item)
        {
            try
            {
                Microsoft.BizTalk.ExplorerOM.BtsOrchestration orchestrationOM = (item as Microsoft.BizTalk.ExplorerOM.BtsOrchestration);
                BtsApplication application = BtsApplication.FromItem(catalog, orchestrationOM.Application);
                return new BtsOrchestration(application, orchestrationOM);
            }

            catch (System.Exception e)
            { throw new BtsException(e); }
        }

        #region Attributes

        public string AssemblyQualifiedName
        {
            get {
                // the returned AssemblyQualifiedName needs to be slightly adjusted
                // in order to be used as a .NET compliant assembly name.
                return orchestration_.AssemblyQualifiedName.Replace(",", ", ").Replace(",  ", ", ").Remove(0, orchestration_.FullName.Length + 2);
            }
        }

        public string Description
        {
            get { return orchestration_.Description; }
            set { orchestration_.Description = value; }
        }

        public BtsHost Host
        {
            get { return BtsHost.FromItem(Catalog, orchestration_.Host); }
        }

        public override string Name
        {
            get { return orchestration_.FullName; }
        }

        public BtsOrchestrationStatus Status
        {
            get { return OrchestrationStatusConverter.FromNativeType(orchestration_.Status); }
        }

        #endregion

        #region Operations

        public void SetHost(BtsHost host)
        {
            if ((host == null) && (this.Host != null))
            {
                orchestration_.Host = null;
                catalog_.SaveChanges();
            }

            else if (String.Compare(host.Name, this.Host.Name, StringComparison.InvariantCultureIgnoreCase) != 0)
            {
                orchestration_.Host = catalog_.BtsCatalogExplorer.Hosts[host.Name];
                catalog_.SaveChanges();
            }
        }

        public void Start()
        {
            orchestration_.Status = Microsoft.BizTalk.ExplorerOM.OrchestrationStatus.Started;
        }

        public void Stop()
        {
            orchestration_.Status = Microsoft.BizTalk.ExplorerOM.OrchestrationStatus.Enlisted;
        }

        public void Enlist()
        {
            orchestration_.Status = Microsoft.BizTalk.ExplorerOM.OrchestrationStatus.Enlisted;
        }

        public void Unenlist()
        {
            orchestration_.Status = Microsoft.BizTalk.ExplorerOM.OrchestrationStatus.Unenlisted;
        }

        #endregion
    }
}
