using System;

namespace BizTalkFactory.Management.Automation
{
    public class BtsPipeline : BtsApplicationArtifact
    {
        private Microsoft.BizTalk.ExplorerOM.Pipeline pipeline_;

        private BtsPipeline(BtsApplication application, Microsoft.BizTalk.ExplorerOM.Pipeline pipeline)
            : base(application)
        {
            pipeline_ = pipeline;
        }

        public static BtsPipeline FromItem(BtsCatalog catalog, object item)
        {
            try
            {
                Microsoft.BizTalk.ExplorerOM.Pipeline pipelineOM = (item as Microsoft.BizTalk.ExplorerOM.Pipeline);
                BtsApplication application = BtsApplication.FromItem(catalog, pipelineOM.Application);
                return new BtsPipeline(application, pipelineOM);
            }

            catch (System.Exception e)
            { throw new BtsException(e); }
        }

        #region Attributes

        public string AssemblyQualifiedName
        {
            get {
                // the returned AssemblyQualifiedName needs to be slightly adjusted
                // in order to be used as a .NET compliant assembly name.
                return pipeline_.AssemblyQualifiedName.Replace(",", ", ").Replace(",  ", ", ").Remove(0, pipeline_.FullName.Length + 2);
            }
        }

        public string Description
        {
            get { return pipeline_.Description; }
            set { pipeline_.Description = value; }
        }

        public override string Name
        {
            get { return pipeline_.FullName; }
        }

        public BtsPipelineType Type
        {
            get { return PipelineTypeConverter.FromNativeType(pipeline_.Type); }
        }

        #endregion

    }
}
