using System;
using System.Collections;
using System.Collections.Generic;

using Microsoft.BizTalk.ApplicationDeployment;

namespace BizTalkFactory.Management.Automation
{
    public class BtsPolicyCollection : IReadOnlyCollectionWrapper<BtsPolicy>
    {
        private new SortedList<String, BtsPolicy> collection_= new SortedList<string, BtsPolicy>();

        internal BtsPolicyCollection(BtsApplication application)
            : base(null)
        {
            RetrievePolicies(application.Catalog, application.Name);
        }

        internal BtsPolicyCollection(BtsCatalog catalog)
            : base(null)
        {
            foreach (BtsApplication application in catalog.Applications)
                RetrievePolicies(catalog, application.Name);
        }

        #region Attributes

        public BtsPolicy this[string name]
        {
            get { return collection_[name]; }
        }

        #endregion

        #region Overrides

        public override ICollection Collection
        {
            get { return (ICollection)collection_.Values; }
        }

        #endregion

        #region Implementation

        private void RetrievePolicies(BtsCatalog catalog, String appName)
        {
            string resourceType = "System.BizTalk:Rules";

            // Microsoft.BizTalk.ApplicationDeployment.Application and
            // Microsoft.BizTalk.ApplicationDeployment.ResourceCollection need to be disposed of.
            // However, ICollection<T> is not IDisposable, so we need to 'cache'
            // the whole collection in the constructor

            BtsApplication btsApplication = catalog.Applications[appName];

            try
            {
                using (Group group = new Group())
                {
                    group.DBName = catalog.Database;
                    group.DBServer = catalog.Instance;

                    Application app = group.Applications[appName];

                    foreach (IResource resourceOM in app.ResourceCollection)
                        if (String.Compare(resourceOM.ResourceType, resourceType, StringComparison.InvariantCultureIgnoreCase) == 0)
                        {
                            BtsResource resource = new BtsResource(btsApplication, resourceOM);
                            BtsPolicy policy = new BtsPolicy(btsApplication, resource);
                            collection_.Add(String.Format("{0}:{1}.{2}", policy.Name, policy.MajorRevision, policy.MinorRevision), policy);
                        }

                }
            }
            catch (System.Exception e)
            {
                collection_.Clear();
                throw new BtsException(e);
            }
        }

        #endregion
    }
}