﻿using System;
using System.Net;

using Microsoft.BizTalk.ExplorerOM;
using Microsoft.BizTalk.Management;
using System.Globalization;

using ReceiveHandler = Microsoft.BizTalk.Management.ReceiveHandler;

namespace BizTalkFactory.Management.Automation
{
    public class BtsReceiveHandler : BtsArtifact 
    {
        private ReceiveHandler receiveHandler_;

        private BtsReceiveHandler(BtsCatalog catalog, ReceiveHandler receiveHandler)
            : base(catalog)
        {
            receiveHandler_ = receiveHandler;
        }

        public static BtsReceiveHandler FromItem(BtsCatalog catalog, object item)
        {
            return new BtsReceiveHandler(catalog, item as ReceiveHandler);
        }

        public void SwitchHost(BtsHost btsHostToSwitchTo)
        {
            SwitchHost(btsHostToSwitchTo.Name);
        }

        public void SwitchHost(string hostNameToSwitchTo)
        {
            try
            {
                receiveHandler_.AutoCommit = false;
                receiveHandler_.LateBoundObject["HostNameToSwitchTo"] = hostNameToSwitchTo;
                receiveHandler_.AutoCommit = true;
                receiveHandler_.CommitObject();
            }
            catch (System.Exception e)
            { 
                throw new BtsException(e); 
            }
        }

        #region attributes

        public override string Name
        {
            get { return Helper.BtsHandlerHelper.ConstructHandlerName(this); }
        }

        public string Description
        {
            get { return receiveHandler_.Description; }
        }

        public BtsHandlerDirection Direction
        {
            get { return BtsHandlerDirection.Receive; }
        }

        public string AdapterName
        {
            get { return receiveHandler_.AdapterName; }
        }

        public string HostName
        {
            get { return receiveHandler_.HostName; }
        }

        public string CustomProps
        {
            get { return receiveHandler_.CustomCfg; }
            set { receiveHandler_.CustomCfg = value; }
        }

        public BtsTransportType TransportType
        {
            get
            {
                foreach (Microsoft.BizTalk.ExplorerOM.ReceiveHandler handler in catalog_.BtsCatalogExplorer.ReceiveHandlers)
                    if (String.Compare(handler.Host.Name, HostName, StringComparison.InvariantCultureIgnoreCase) == 0 &&
                        String.Compare(handler.TransportType.Name, AdapterName, StringComparison.InvariantCultureIgnoreCase) == 0)
                        return new BtsTransportType(Catalog, handler.TransportType);

                System.Diagnostics.Debug.Assert(false);
                throw new BtsException(new NotImplementedException());
            }
        }

        #endregion
    }
}
