using System;

using Microsoft.BizTalk.ExplorerOM;

namespace BizTalkFactory.Management.Automation
{
    public class BtsReceiveLocation : BtsArtifact
    {
        private ReceiveLocation receiveLocation_;

        private BtsReceiveLocation(BtsCatalog catalog, ReceiveLocation location)
            : base(catalog)
        {
            receiveLocation_ = location;
        }

        public static BtsReceiveLocation FromItem(BtsCatalog catalog, object item)
        {
            return new BtsReceiveLocation(catalog, item as ReceiveLocation);
        }

        #region Attributes

        public string Description
        {
            get { return receiveLocation_.Description; }
            set { receiveLocation_.Description = value; }
        }

        public bool Enable
        {
            get { return receiveLocation_.Enable; }
            set { receiveLocation_.Enable = value; }
        }

        public override string Name
        {
            get { return receiveLocation_.Name; }
        }

        public string Address
        {
            get { return receiveLocation_.Address; }
            set { receiveLocation_.Address = value; }
        }

        public DateTime EndDate
        {
            get { return receiveLocation_.EndDate; }
            set { receiveLocation_.EndDate = value; }
        }

        public bool EndDateEnabled
        {
            get { return receiveLocation_.EndDateEnabled; }
            set { receiveLocation_.EndDateEnabled = value; }
        }

        public DateTime FromTime
        {
            get { return receiveLocation_.FromTime; }
            set { receiveLocation_.FromTime = value; }
        }

        public string PublicAddress
        {
            get { return receiveLocation_.PublicAddress; }
            set { receiveLocation_.PublicAddress = value; }
        }

        public BtsReceiveHandler ReceiveHandler
        {
            get
            {
                return Helper.BtsHandlerHelper.FindReceiveHandler(
                    catalog_
                    , receiveLocation_.ReceiveHandler.Host.Name
                    , receiveLocation_.ReceiveHandler.TransportType.Name
                    );
            }
            set
            {
                // find ExplorerOM ReceiveHandler

                BtsReceiveHandler handler = value;
                ReceiveHandler newReceiveHandler = null;

                foreach (ReceiveHandler receiveHandler in catalog_.BtsCatalogExplorer.ReceiveHandlers)
                    if (String.Compare(receiveHandler.Host.Name, handler.HostName, StringComparison.InvariantCultureIgnoreCase) == 0 &&
                        String.Compare(receiveHandler.TransportType.Name, handler.TransportType.Name, StringComparison.InvariantCultureIgnoreCase) == 0)
                    {
                        newReceiveHandler = receiveHandler;
                        break;
                    }

                if (newReceiveHandler == null)
                    throw new BtsException(String.Format(
                        Resources.BizTalkMgmt_InvalidReceiveHandler
                        , handler.HostName
                        , handler.TransportType.Name));

                // update Receive Location's ReceiveHandler

                receiveLocation_.ReceiveHandler = newReceiveHandler;
                catalog_.SaveChanges();
            }
        }

        public BtsPipeline ReceivePipeline
        {
            get { return BtsPipeline.FromItem(Catalog, receiveLocation_.ReceivePipeline); }
            set { receiveLocation_.ReceivePipeline = Catalog.BtsCatalogExplorer.Pipelines[value.Name]; }
        }

        public string ReceivePipelineData
        {
            get { return receiveLocation_.ReceivePipelineData; }
            set { receiveLocation_.ReceivePipelineData = value; }
        }

        public BtsReceivePort ReceivePort
        {
            get { return BtsReceivePort.FromItem(Catalog, receiveLocation_.ReceivePort); }
        }

        public BtsPipeline SendPipeline
        {
            get { return BtsPipeline.FromItem(Catalog, receiveLocation_.SendPipeline); }
            set { receiveLocation_.SendPipeline = Catalog.BtsCatalogExplorer.Pipelines[value.Name]; }
        }

        public string SendPipelineData
        {
            get { return receiveLocation_.SendPipelineData; }
            set { receiveLocation_.SendPipelineData = value; }
        }

        public bool ServiceWindowEnabled
        {
            get { return receiveLocation_.ServiceWindowEnabled; }
            set { receiveLocation_.ServiceWindowEnabled = value; }
        }

        public DateTime StartDate
        {
            get { return receiveLocation_.StartDate; }
            set { receiveLocation_.StartDate = value; }
        }

        public bool StartDateEnabled
        {
            get { return receiveLocation_.StartDateEnabled; }
            set { receiveLocation_.StartDateEnabled = value; }
        }

        public DateTime ToTime
        {
            get { return receiveLocation_.ToTime; }
            set { receiveLocation_.ToTime = value; }
        }

        public BtsTransportType TransportType
        {
            get { return new BtsTransportType(Catalog, receiveLocation_.TransportType); }
            set { receiveLocation_.TransportType = value.transportType_; }
        }

        public string TransportTypeData
        {
            get { return receiveLocation_.TransportTypeData; }
            set { receiveLocation_.TransportTypeData = value; }
        }

        #endregion

        #region Operations

        public void SetName(string value)
        {
            receiveLocation_.Name = value;
        }

        #endregion
    }
}
