using System;
using System.Collections;
using System.Collections.Generic;

using Microsoft.BizTalk.ExplorerOM;

namespace BizTalkFactory.Management.Automation
{
    public class BtsReceiveLocationCollection : IReadOnlyCollectionWrapper<BtsReceiveLocation>
    {
        private new SortedList<String, BtsReceiveLocation> collection_ = new SortedList<string, BtsReceiveLocation>();

        internal BtsReceiveLocationCollection(BtsCatalog catalog)
            : base(null)
        {
            foreach (Application application in catalog.BtsCatalogExplorer.Applications)
                foreach (ReceivePort receivePort in application.ReceivePorts)
                    foreach (ReceiveLocation receiveLocation in receivePort.ReceiveLocations)
                        collection_.Add(receiveLocation.Name, BtsReceiveLocation.FromItem(catalog, receiveLocation));
        }

        internal BtsReceiveLocationCollection(BtsApplication application)
            : base(null)
        {
            foreach (ReceivePort receivePort in application.Catalog.BtsCatalogExplorer.Applications[application.Name].ReceivePorts)
                foreach (ReceiveLocation receiveLocation in receivePort.ReceiveLocations)
                    collection_.Add(receiveLocation.Name, BtsReceiveLocation.FromItem(application.Catalog, receiveLocation));
        }

        internal BtsReceiveLocationCollection(BtsReceivePort receivePort)
            : base(null)
        {
            BtsCatalogExplorer catalog = receivePort.Catalog.BtsCatalogExplorer;
            Application applicationOM = catalog.Applications[receivePort.Application.Name];
            ReceivePort receivePortOM = applicationOM.ReceivePorts[receivePort.Name];

            foreach (ReceiveLocation receiveLocation in receivePortOM.ReceiveLocations)
                collection_.Add(receiveLocation.Name, BtsReceiveLocation.FromItem(receivePort.Catalog, receiveLocation));
        }

        #region Overrides

        public override ICollection Collection
        {
            get { return (ICollection)collection_.Values; }
        }

        #endregion
    }
}
