using System;

using Microsoft.BizTalk.ExplorerOM;

namespace BizTalkFactory.Management.Automation
{
    public class BtsReceivePort : BtsApplicationArtifact
    {
        private ReceivePort receivePort_;

        private BtsReceivePort(BtsApplication application, ReceivePort receivePort)
            : base(application)
        {
            receivePort_ = receivePort;
        }

        public static BtsReceivePort FromItem(BtsCatalog catalog, object item)
        {
            try
            {
                ReceivePort receivePortOM = (item as ReceivePort);
                BtsApplication application = BtsApplication.FromItem(catalog, receivePortOM.Application);
                return new BtsReceivePort(application, receivePortOM);
            }

            catch (System.Exception e)
            { throw new BtsException(e); }
        }

        #region Attributes

        public string Description
        {
            get { return receivePort_.Description; }
            set { receivePort_.Description = value; }
        }

        public override string Name
        {
            get { return receivePort_.Name; }
        }

        public bool IsTwoWay
        {
            get { return receivePort_.IsTwoWay; }
        }

        public void SetName(string name)
        {
            receivePort_.Name = name;
        }

        public BtsReceiveLocationCollection ReceiveLocations
        {
            get { return new BtsReceiveLocationCollection(this); }
        }

        #endregion

        #region Operations

        public void RemoveReceiveLocation(string name)
        {
            receivePort_.RemoveReceiveLocation(receivePort_.ReceiveLocations[name]);
        }

        public void RemoveReceiveLocation(BtsReceiveLocation receiveLocation)
        {
            RemoveReceiveLocation(receiveLocation.Name);
        }

        #endregion
    }
}
