﻿using System;
using System.Collections;
using System.Collections.Generic;

using Microsoft.BizTalk.ExplorerOM;

namespace BizTalkFactory.Management.Automation
{
    public class ReferenceCollectionBase : IReadOnlyCollectionWrapper<BtsReference>
    {
        protected new IList<BtsReference> collection_ = new List<BtsReference>();

        public ReferenceCollectionBase(BtsCatalog catalog, Application application, ICollection collection)
            : base(null)
        {
            BtsApplication app = BtsApplication.FromItem(catalog, application);
            foreach (Application reference in collection)
                collection_.Add(new BtsReference(app, reference.Name));
        }

        public bool Contains(BtsApplication application)
        {
            foreach (BtsReference reference in Collection)
                if (String.Compare(reference.Name, application.Name, StringComparison.InvariantCultureIgnoreCase) == 0)
                    return true;

            return false;
        }

        #region Overrides

        public override ICollection Collection
        {
            get { return (ICollection) collection_; }
        }

        #endregion
    }

    public class BtsReferenceCollection : ReferenceCollectionBase
    {
        public BtsReferenceCollection(BtsCatalog catalog, Application application)
            : base(catalog, application, application.References)
        {
        }
    }

    public class BtsBackReferenceCollection : ReferenceCollectionBase
    {
        public BtsBackReferenceCollection(BtsCatalog catalog, Application application)
            : base(catalog, application, application.BackReferences)
        {
        }
    }
}
