using System;
using System.Collections.Generic;

using Microsoft.BizTalk.ApplicationDeployment;

namespace BizTalkFactory.Management.Automation
{
    public class BtsResource : BtsArtifact
    {
        private BtsApplication application_;
        private string type_ = String.Empty;
        private string luid_ = String.Empty;
        private bool show_ = true;

        internal byte[] cabcontent_ = new byte[] { };
        internal readonly IDictionary<string, object> properties_ = new Dictionary<string, object>();

        internal BtsResource(BtsApplication application, Microsoft.BizTalk.ApplicationDeployment.IResource resource)
            : base(application.Catalog)
        {
            application_ = application;
            type_ = resource.ResourceType;
            luid_ = resource.Luid;
            show_ = resource.ShowResource;

            cabcontent_ = resource.CabContent;

            foreach (KeyValuePair<string, object> pair in resource.Properties)
                properties_.Add(pair.Key, pair.Value);
        }

        #region Attributes

        public BtsApplication Application
        {
            get { return application_; }
        }

        public byte[] CabContent
        {
            get { return cabcontent_; }
        }

        public string DisplayName
        {
            get
            {
                if ((type_ == "System.BizTalk:File") || (type_ == "System.BizTalk:PreProcessingScript") || (type_ == "System.BizTalk:PostProcessingScript"))
                    return (application_.Name + ":" + luid_.Substring(luid_.IndexOf(":", StringComparison.Ordinal) + 1));
                if ((type_ == "System.BizTalk:Rules"))
                    return luid_.Replace("RULE/", "").Replace("/", ":");
                return luid_;
            }
        }

        public string Luid
        {
            get { return luid_; }
        }

        public override string Name
        {
            get { return Luid; }
        }

        public IDictionary<string, object> Properties
        {
            get { return properties_; }
        }

        public string ResourceType
        {
            get { return type_; }
        }

        public bool ShowResource
        {
            get { return show_; }
        }

        #endregion

        #region Bindings

        public void ExportBinding(string destination, bool includeGlobalPartyBinding)
        {
            Catalog.ExportBinding(this, destination, includeGlobalPartyBinding);
        }

        #endregion

        #region Properties

        public string SourceLocation
        {
            get
            {
                if (GetProperty("SourceLocation") != null)
                    return (GetProperty("SourceLocation") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "SourceLocation"));
            }
        }

        public string DestinationLocation
        {
            get
            {
                if (GetProperty("DestinationLocation") != null)
                    return (GetProperty("DestinationLocation") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "DestinationLocation"));
            }
            set
            {
                if (GetProperty("DestinationLocation") != null)
                    SetProperty("DestinationLocation", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "DestinationLocation"));
            }
        }

        public bool GacOnAdd
        {
            get
            {
                if (GetProperty("GacOnAdd") != null)
                    return Boolean.Parse(GetProperty("GacOnAdd") as String);
                else if (GetProperty("GacNow") != null)
                    return Boolean.Parse(GetProperty("GacNow") as String);
                else if (GetProperty("UpdateGac") != null)
                    return Boolean.Parse(GetProperty("UpdateGac") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "GacOnAdd"));
            }
            set
            {
                if (GetProperty("GacOnAdd") != null)
                    SetProperty("GacOnAdd", value);
                else if (GetProperty("GacNow") != null)
                    SetProperty("GacNow", value);
                else if (GetProperty("UpdateGac") != null)
                    SetProperty("UpdateGac", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "GacOnAdd"));
            }
        }

        public bool GacOnInstall
        {
            get
            {
                if (GetProperty("GacOnInstall") != null)
                    return Boolean.Parse(GetProperty("GacOnInstall") as String);
                else if (GetProperty("Gacutil") != null)
                    return Boolean.Parse(GetProperty("Gacutil") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "GacOnInstall"));
            }
            set
            {
                if (GetProperty("GacOnInstall") != null)
                    SetProperty("GacOnInstall", value);
                else if (GetProperty("Gacutil") != null)
                    SetProperty("Gacutil", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "GacOnInstall"));
            }
        }

        public bool GacOnImport
        {
            get
            {
                if (GetProperty("GacOnImport") != null)
                    return Boolean.Parse(GetProperty("GacOnImport") as String);
                else if (GetProperty("UpdateGacOnImport") != null)
                    return Boolean.Parse(GetProperty("UpdateGacOnImport") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "GacOnImport"));
            }
            set
            {
                if (GetProperty("GacOnImport") != null)
                    SetProperty("GacOnImport", value);
                else if (GetProperty("UpdateGacOnImport") != null)
                    SetProperty("UpdateGacOnImport", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "GacOnImport"));
            }
        }

        public bool Regasm
        {
            get
            {
                if (GetProperty("Regasm") != null)
                    return Boolean.Parse(GetProperty("Regasm") as String);
                else if (GetProperty("RegasmOnInstall") != null)
                    return Boolean.Parse(GetProperty("RegasmOnInstall") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "Regasm"));
            }
            set
            {
                if (GetProperty("Regasm") != null)
                    SetProperty("Regasm", value);
                else if (GetProperty("RegasmOnInstall") != null)
                    SetProperty("RegasmOnInstall", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "Regasm"));
            }
        }

        public bool Regsvcs
        {
            get
            {
                if (GetProperty("Regsvcs") != null)
                    return Boolean.Parse(GetProperty("Regsvcs") as String);
                else if (GetProperty("RegSvcsOnInstall") != null)
                    return Boolean.Parse(GetProperty("RegSvcsOnInstall") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "Regsvcs"));
            }
            set
            {
                if (GetProperty("Regsvcs") != null)
                    SetProperty("Regsvcs", value);
                else if (GetProperty("RegSvcsOnInstall") != null)
                    SetProperty("RegSvcsOnInstall", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "Regsvcs"));
            }
        }

        public bool RegSvr32
        {
            get
            {
                if (GetProperty("RegSvr32") != null)
                    return Boolean.Parse(GetProperty("RegSvr32") as String);
                else if (GetProperty("Regsvr32OnInstall") != null)
                    return Boolean.Parse(GetProperty("Regsvr32OnInstall") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "RegSvr32"));
            }
            set
            {
                if (GetProperty("RegSvr32") != null)
                    SetProperty("RegSvr32", value);
                else if (GetProperty("Regsvr32OnInstall") != null)
                    SetProperty("Regsvr32OnInstall", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "RegSvr32"));
            }
        }

        public string TargetEnvironment
        {
            get
            {
                if (GetProperty("TargetEnvironment") != null)
                    return (GetProperty("TargetEnvironment") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "TargetEnvironment"));
            }
            set
            {
                if (GetProperty("TargetEnvironment") != null)
                    SetProperty("TargetEnvironment", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "TargetEnvironment"));
            }
        }

        public string Arguments
        {
            get
            {
                if (GetProperty("Args") != null)
                    return (GetProperty("Args") as String);

                throw new KeyNotFoundException(
                    String.Format(
                          Resources.BizTalkMgmt_InvalidResourceProperty
                        , type_
                        , "Args"));
            }
            set
            {
                if (GetProperty("Args") != null)
                    SetProperty("Args", value);
                else
                    throw new KeyNotFoundException(
                        String.Format(
                              Resources.BizTalkMgmt_InvalidResourceProperty
                            , type_
                            , "Args"));
            }
        }

        public object GetProperty(string name)
        {
            if (properties_.ContainsKey(name))
                return properties_[name];
            return null;
        }

        public void SetProperty(string name, object value)
        {
            // only allow strings to be stored

            value = Convert.ToString(value);

            // prevent inconsistent property names

            if (String.Compare(name, "GacOnAdd", true) == 0) name = "UpdateGac";
            if (String.Compare(name, "GacNow", true) == 0) name = "UpdateGac";
            if (String.Compare(name, "GacOnInstall", true) == 0) name = "Gacutil";
            if (String.Compare(name, "GacOnImport", true) == 0) name = "UpdateGacOnImport";
            if (String.Compare(name, "RegasmOnInstall", true) == 0) name = "Regasm";
            if (String.Compare(name, "RegsvcsOnInstall", true) == 0) name = "Regsvcs";
            if (String.Compare(name, "RegSvr32OnInstall", true) == 0) name = "RegSvr32";

            // update properties

            if (!properties_.ContainsKey(name))
                properties_.Add(name, value);
            properties_[name] = value;

            // TODO: improve performances

            using (Group deploymentGroup = new Group())
            {
                deploymentGroup.DBName = Catalog.Database;
                deploymentGroup.DBServer = Catalog.Instance;

                if (!deploymentGroup.Options.ContainsKey("DoNotRefresh"))
                    deploymentGroup.Options.Add("DoNotRefresh", true);

                try
                {
                    Application app = (Application)deploymentGroup.CreateInstance(typeof(Application));
                    app.Name = Application.Name;

                    IResource[] resources = new IResource[1];
                    resources[0] = new Resource(ResourceType, Luid);
                    resources[0].Properties = Properties;

                    IResourceManager manager = SdmParser.GetInstance().GetResourceManager(ResourceType);

                    foreach (ResourceManagerPropertyType type in manager.SupportedProperties)
                    {
                        if (((type.Type == "bool") && type.ShowInOptionsUI) && !resources[0].Properties.ContainsKey(type.Name))
                            resources[0].Properties.Add(type.Name, type.DefaultValue);
                    }

                    app.ResourceCollection.Add(resources, true);

                    return;
                }
                catch (System.Exception e)
                {
                    deploymentGroup.Abort();
                    throw new BtsException(e);
                }
            }
        }

        #endregion
    }
}