using System;
using System.Collections;
using System.Collections.Generic;

using Microsoft.BizTalk.ApplicationDeployment;

namespace BizTalkFactory.Management.Automation
{
    public class BtsResourceCollection : IReadOnlyCollectionWrapper<BtsResource>
    {
        private new SortedList<String, BtsResource> collection_= new SortedList<string,BtsResource>();

        internal BtsResourceCollection(BtsCatalog catalog)
            : this(catalog, String.Empty)
        {
        }

        internal BtsResourceCollection(BtsCatalog catalog, string resourceType)
            : base(null)
        {
            foreach (BtsApplication application in catalog.Applications)
                RetrieveResources(catalog, application.Name, resourceType);
        }

        internal BtsResourceCollection(BtsApplication application)
            : this(application, String.Empty)
        {
        }

        internal BtsResourceCollection(BtsApplication application, string resourceType)
            : base(null)
        {
            RetrieveResources(application.Catalog, application.Name, resourceType);
        }

        #region Attributes

        public BtsResource this[string name]
        {
            get { return collection_[name]; }
        }

        #endregion

        #region Overrides

        public override ICollection Collection
        {
            get { return (ICollection)collection_.Values; }
        }

        #endregion

        #region Implementation

        private void RetrieveResources(BtsCatalog catalog, String appName, string resourceType)
        {
            // Microsoft.BizTalk.ApplicationDeployment.Application and
            // Microsoft.BizTalk.ApplicationDeployment.ResourceCollection need to be disposed of.
            // However, ICollection<T> is not IDisposable, so we need to 'cache'
            // the whole collection in the constructor

            BtsApplication btsApplication = catalog.Applications[appName];

            try
            {
                using (Group group = new Group())
                {
                    group.DBName = catalog.Database;
                    group.DBServer = catalog.Instance;

                    Application app = group.Applications[appName];

                    foreach (IResource resource in app.ResourceCollection)
                        if (String.IsNullOrEmpty(resourceType) || String.Compare(resource.ResourceType, resourceType, StringComparison.InvariantCultureIgnoreCase) == 0)
                            collection_.Add(resource.Luid, new BtsResource(btsApplication, resource));

                }
            }
            catch (System.Exception e)
            {
                collection_.Clear();
                throw new BtsException(e);
            }
        }

        #endregion
    }
}