using System;

namespace BizTalkFactory.Management.Automation
{
    public class BtsSchema : BtsApplicationArtifact
    {
        private Microsoft.BizTalk.ExplorerOM.Schema schema_;

        private BtsSchema(BtsApplication application, Microsoft.BizTalk.ExplorerOM.Schema schema)
            : base(application)
        {
            schema_ = schema;
        }

        public static BtsSchema FromItem(BtsCatalog catalog, object item)
        {
            try
            {
                Microsoft.BizTalk.ExplorerOM.Schema schemaOM = (item as Microsoft.BizTalk.ExplorerOM.Schema);
                BtsApplication application = BtsApplication.FromItem(catalog, schemaOM.Application);
                return new BtsSchema(application, schemaOM);
            }

            catch (System.Exception e)
            { throw new BtsException(e); }
        }

        #region Attributes

        public string AssemblyQualifiedName
        {
            get {
                // the returned AssemblyQualifiedName needs to be slightly adjusted
                // in order to be used as a .NET compliant assembly name.
                return schema_.AssemblyQualifiedName.Replace(",", ", ").Replace(",  ", ", ").Remove(0, schema_.FullName.Length + 2);
            }
        }

        public string Description
        {
            get { return schema_.Description; }
            set { schema_.Description = value; }
        }

        public override string Name
        {
            get { return schema_.FullName; }
        }

        public string RootName
        {
            get { return schema_.RootName; }
        }

        public string TargetNamespace
        {
            get { return schema_.TargetNameSpace; }
        }

        public BtsSchemaType Type
        {
            get { return SchemaTypeConverter.FromNativeType(schema_.Type); }
        }

        #endregion

    }
}
