﻿using System;
using System.Net;

using Microsoft.BizTalk.ExplorerOM;
using Microsoft.BizTalk.Management;
using System.Globalization;

namespace BizTalkFactory.Management.Automation
{
    public class BtsSendHandler : BtsArtifact 
    {
        private SendHandler2 sendHandler_;
        
        private BtsSendHandler(BtsCatalog catalog, SendHandler2 sendHandler)
            : base(catalog)
        {
            sendHandler_ = sendHandler;
        }

        public static BtsSendHandler FromItem(BtsCatalog catalog, object item)
        {
            return new BtsSendHandler(catalog, item as SendHandler2);
        }

        public void SwitchHost(BtsHost btsHostToSwitchTo)
        {
            SwitchHost(btsHostToSwitchTo.Name);
        }

        public void SwitchHost(string hostNameToSwitchTo)
        {
            try
            {
                sendHandler_.AutoCommit = false;
                sendHandler_.LateBoundObject["HostNameToSwitchTo"] = hostNameToSwitchTo;
                sendHandler_.LateBoundObject["CustomCfg"] = CustomProps;
                sendHandler_.AutoCommit = true;
                sendHandler_.CommitObject();
            }
            catch (System.Exception e)
            {
                throw new BtsException(e);
            }
        }

        #region attributes

        public override string Name
        {
            get { return Helper.BtsHandlerHelper.ConstructHandlerName(this); }
        }

        public string Description
        {
            get { return sendHandler_.Description; }
        }

        public BtsHandlerDirection Direction
        {
            get { return BtsHandlerDirection.Send; }
        }

        public string AdapterName
        {
            get { return sendHandler_.AdapterName; }
        }

        public string HostName
        {
            get { return sendHandler_.HostName; }
        }

        public string CustomProps
        {
            get { return sendHandler_.CustomCfg; }
            set { sendHandler_.CustomCfg = value; }
        }

        public bool Default
        {
            get { return sendHandler_.IsDefault; }
            set { sendHandler_.IsDefault = value; }
        }

        public BtsTransportType TransportType
        {
            get
            {
                foreach (Microsoft.BizTalk.ExplorerOM.SendHandler handler in catalog_.BtsCatalogExplorer.SendHandlers)
                    if (String.Compare(handler.Host.Name, HostName, StringComparison.InvariantCultureIgnoreCase) == 0 &&
                        String.Compare(handler.TransportType.Name, AdapterName, StringComparison.InvariantCultureIgnoreCase) == 0)
                        return new BtsTransportType(Catalog, handler.TransportType);

                System.Diagnostics.Debug.Assert(false);
                throw new BtsException(new NotImplementedException());
            }
        }

        #endregion
    }
}
