using System;

using Microsoft.BizTalk.ExplorerOM;

namespace BizTalkFactory.Management.Automation
{
    public class BtsSendPort : BtsApplicationArtifact
    {
        private SendPort sendPort_;

        private BtsSendPort(BtsApplication application, SendPort sendPort)
            : base(application)
        {
            sendPort_ = sendPort;
        }

        public static BtsSendPort FromItem(BtsCatalog catalog, object item)
        {
            try
            {
                SendPort sendPortOM = (item as SendPort);
                BtsApplication application = BtsApplication.FromItem(catalog, sendPortOM.Application);
                return new BtsSendPort(application, sendPortOM);
            }

            catch (System.Exception e)
            { throw new BtsException(e); }
        }

        #region Attributes

        public string Description
        {
            get { return sendPort_.Description; }
            set { sendPort_.Description = value; }
        }

        public override string Name
        {
            get { return sendPort_.Name; }
        }

        public string Filter
        {
            get { return sendPort_.Filter; }
            set { sendPort_.Filter = value; }
        }

        public bool IsDynamic
        {
            get { return sendPort_.IsDynamic; }
        }

        public bool IsTwoWay
        {
            get { return sendPort_.IsTwoWay; }
        }

        public bool OrderedDelivery
        {
            get { return sendPort_.OrderedDelivery; }
            set { sendPort_.OrderedDelivery = value; }
        }

        public BtsTransportInfo PrimaryTransport
        {
            get { return new BtsTransportInfo(Catalog, sendPort_, sendPort_.PrimaryTransport); }
        }

        public int Priority
        {
            get { return sendPort_.Priority; }
            set { sendPort_.Priority = value; }
        }

        public BtsPipeline ReceivePipeline
        {
            get { return BtsPipeline.FromItem(Catalog, sendPort_.ReceivePipeline); }
            set { sendPort_.ReceivePipeline = Catalog.BtsCatalogExplorer.Pipelines[value.Name]; }
        }

        public string ReceivePipelineData
        {
            get { return sendPort_.ReceivePipelineData; }
            set { sendPort_.ReceivePipelineData = value; }
        }

        public bool RouteFailedMessage
        {
            get { return sendPort_.RouteFailedMessage; }
            set { sendPort_.RouteFailedMessage = value; }
        }

        public BtsPipeline SendPipeline
        {
            get { return BtsPipeline.FromItem(Catalog, sendPort_.SendPipeline); }
            set { sendPort_.SendPipeline = Catalog.BtsCatalogExplorer.Pipelines[value.Name]; }
        }

        public string SendPipelineData
        {
            get { return sendPort_.SendPipelineData; }
            set { sendPort_.SendPipelineData = value; }
        }

        public BtsTransportInfo SecondaryTransport
        {
            get { return new BtsTransportInfo(Catalog, sendPort_, sendPort_.SecondaryTransport); }
        }

        public BtsPortStatus Status
        {
            get { return PortStatusConverter.FromNativeType(sendPort_.Status); }
            set { sendPort_.Status = PortStatusConverter.ToNativeType(value); }
        }

        public bool StopSendingOnFailure
        {
            get { return sendPort_.StopSendingOnFailure; }
            set { sendPort_.StopSendingOnFailure = value; }
        }

        public BtsSendHandler SendHandler
        {
            get
            {
                return Helper.BtsHandlerHelper.FindSendHandler(
                    catalog_
                    , sendPort_.PrimaryTransport.SendHandler.Host.Name
                    , sendPort_.PrimaryTransport.TransportType.Name);
            }
            set
            {
                PrimaryTransport.SendHandler = value;
            }
        }

        public BtsTrackingTypes Tracking
        {
            get { return TrackingTypesConverter.FromNativeType(sendPort_.Tracking); }
            set { sendPort_.Tracking = TrackingTypesConverter.ToNativeType(value); }
        }

        #endregion

        #region Operations

        public void SetName(string value)
        {
            sendPort_.Name = value;
        }

        public void Start()
        {
            sendPort_.Status = Microsoft.BizTalk.ExplorerOM.PortStatus.Started;
        }

        public void Stop()
        {
            sendPort_.Status = Microsoft.BizTalk.ExplorerOM.PortStatus.Stopped;
        }

        public void Enlist()
        {
            sendPort_.Status = Microsoft.BizTalk.ExplorerOM.PortStatus.Stopped;
        }

        public void Unenlist()
        {
            sendPort_.Status = Microsoft.BizTalk.ExplorerOM.PortStatus.Bound;
        }

        #endregion
    }
}
