using System;

using Microsoft.BizTalk.ExplorerOM;

namespace BizTalkFactory.Management.Automation
{
    public class BtsSendPortGroup : BtsApplicationArtifact
    {
        private SendPortGroup sendPortGroup_;

        private BtsSendPortGroup(BtsApplication application, SendPortGroup sendPortGroup)
            : base(application)
        {
            sendPortGroup_ = sendPortGroup;
        }

        public static BtsSendPortGroup FromItem(BtsCatalog catalog, object item)
        {
            try
            {
                SendPortGroup sendPortGroupOM = (item as SendPortGroup);
                BtsApplication application = BtsApplication.FromItem(catalog, sendPortGroupOM.Application);
                return new BtsSendPortGroup(application, sendPortGroupOM);
            }

            catch (System.Exception e) { throw new BtsException(e); }
        }

        #region Attributes

        public string Description
        {
            get { return sendPortGroup_.Description; }
            set { sendPortGroup_.Description = value; }
        }

        public override string Name
        {
            get { return sendPortGroup_.Name; }
        }

        public void SetName(string value)
        {
            sendPortGroup_.Name = value;
        }

        public BtsPortStatus Status
        {
            get { return PortStatusConverter.FromNativeType(sendPortGroup_.Status); }
            set { sendPortGroup_.Status = PortStatusConverter.ToNativeType(value); }
        }

        #endregion

        #region Send Ports

        public BtsSendPortCollection SendPorts
        {
            get { return new BtsSendPortCollection(this); }
        }

        #endregion

        #region Operations

        public void Start()
        {
            sendPortGroup_.Status = Microsoft.BizTalk.ExplorerOM.PortStatus.Started;
        }

        public void Stop()
        {
            sendPortGroup_.Status = Microsoft.BizTalk.ExplorerOM.PortStatus.Stopped;
        }

        public void Enlist()
        {
            sendPortGroup_.Status = Microsoft.BizTalk.ExplorerOM.PortStatus.Stopped;
        }

        public void Unenlist()
        {
            sendPortGroup_.Status = Microsoft.BizTalk.ExplorerOM.PortStatus.Bound;
        }

        #endregion
    }
}
