using System;

using Microsoft.BizTalk.ExplorerOM;

namespace BizTalkFactory.Management.Automation
{
    public class BtsTransportInfo
    {
        private BtsCatalog catalog_; // Automation object
        private TransportInfo transport_; // ExplorerOM object

        internal BtsTransportInfo(BtsCatalog catalog, SendPort sendPort, TransportInfo transport)
        {
            System.Diagnostics.Debug.Assert(ReferenceEquals(sendPort, transport.SendPort));
            catalog_ = catalog;
            transport_ = transport;
        }

        #region Attributes

        public string Address
        {
            get
            {
                return transport_.Address;
            }
            set
            {
                transport_.Address = value;
                catalog_.SaveChanges();
            }
        }

        //public NotificationTypes DeliveryNotification
        //{
        //    get
        //    {
        //        return null;
        //    }
        //    set
        //    {
        //        catalog_.SaveChanges();
        //    }
        //}
    
        public DateTime FromTime
        {
            get
            {
                return transport_.FromTime;
            }
            set
            {
                transport_.FromTime = value;
                catalog_.SaveChanges();
            }
        }
        
        public bool OrderedDelivery
        {
            get
            {
                return transport_.OrderedDelivery;
            }
            set
            {
                transport_.OrderedDelivery = value;
                catalog_.SaveChanges();
            }
        }
        
        public bool Primary
        {
            get { return transport_.Primary; }
        }

        public int RetryCount
        {
            get
            {
                return transport_.RetryCount;
            }
            set
            {
                transport_.RetryCount = value;
                catalog_.SaveChanges();
            }
        }
        
        public int RetryInterval
        {
            get
            {
                return transport_.RetryInterval;
            }
            set
            {
                transport_.RetryInterval = value;
                catalog_.SaveChanges();
            }
        }
        
        public BtsSendHandler SendHandler
        {
            get
            {
                return BtsSendHandler.FromItem(catalog_, transport_.SendHandler);
            }
            set
            {
                // find ExplorerOM SendHandler

                BtsSendHandler handler = value;
                SendHandler newSendHandler = null;

                foreach (SendHandler sendHandler in catalog_.BtsCatalogExplorer.SendHandlers)
                    if (String.Compare(sendHandler.Host.Name, handler.HostName, StringComparison.InvariantCultureIgnoreCase) == 0 &&
                        String.Compare(sendHandler.TransportType.Name, handler.TransportType.Name, StringComparison.InvariantCultureIgnoreCase) == 0)
                    {
                        newSendHandler = sendHandler;
                        break;
                    }

                if (newSendHandler == null)
                    throw new BtsException(String.Format(
                        Resources.BizTalkMgmt_InvalidSendHandler
                        , handler.HostName
                        , handler.TransportType.Name));

                // update Send Port's SendHandler

                transport_.SendHandler = newSendHandler;
                catalog_.SaveChanges();
            }
        }
        
        public BtsSendPort SendPort
        {
            get { return BtsSendPort.FromItem(catalog_, transport_.SendPort); }
        }
        
        public bool ServiceWindowEnabled
        {
            get
            {
                return transport_.ServiceWindowEnabled;
            }
            set
            {
                transport_.ServiceWindowEnabled = value;
                catalog_.SaveChanges();
            }
        }
       
        public DateTime ToTime
        {
            get
            {
                return transport_.ToTime;
            }
            set
            {
                transport_.ToTime = value;
                catalog_.SaveChanges();
            }
        }

        public BtsTransportType TransportType
        {
            get
            {
                return new BtsTransportType(catalog_, transport_.TransportType);
            }

            set
            {
                transport_.TransportType = value.transportType_;
                catalog_.SaveChanges();
            }
        }

        public string TransportTypeData
        {
            get
            {
                return transport_.TransportTypeData;
            }
            set
            {
                transport_.TransportTypeData = value;
                catalog_.SaveChanges();
            }
        }

        #endregion
    }
}
