﻿using System;
using System.Reflection;
using System.Security;
using System.Security.Permissions;
using System.Security.Policy;

namespace BizTalkFactory.Management.Automation.Helper
{
    public class AppDomainHelper
    {
        public static bool IsManagedAssembly(string path)
        {
            AppDomain domain = null;

            try
            {
                domain = CreateAppDomain("IsManagedAssembly");

                ManagedAssemblyHelper proxy = 
                    (ManagedAssemblyHelper) domain.CreateInstanceFromAndUnwrap(
                          Assembly.GetExecutingAssembly().Location
                        , typeof(ManagedAssemblyHelper).FullName);

                return proxy.IsManagedAssembly(path);
            }
            finally
            {
                AppDomain.CurrentDomain.AssemblyResolve -= new ResolveEventHandler(AppDomain_AssemblyResolve);
                AppDomain.Unload(domain);
            }
        }

        public static bool IsBizTalkAssembly(string path)
        {
            AppDomain domain = null;

            try
            {
                AppDomain.CurrentDomain.AssemblyResolve += new ResolveEventHandler(AppDomain_AssemblyResolve);

                domain = CreateAppDomain("IsBizTalkAssembly");

                ManagedAssemblyHelper proxy =
                    (ManagedAssemblyHelper)domain.CreateInstanceFromAndUnwrap(
                          Assembly.GetExecutingAssembly().Location
                        , typeof(ManagedAssemblyHelper).FullName);

                return proxy.IsBizTalkAssembly(path);
            }
            finally
            {
                AppDomain.CurrentDomain.AssemblyResolve -= new ResolveEventHandler(AppDomain_AssemblyResolve);
                AppDomain.Unload(domain);
            }
        }

        private static AppDomain CreateAppDomain(string appDomainName)
        {
            AppDomainSetup appDomainSetup = new AppDomainSetup();
            appDomainSetup.ApplicationBase = AppDomain.CurrentDomain.BaseDirectory;

            AppDomain domain = AppDomain.CreateDomain(
                  appDomainName
                , new Evidence(AppDomain.CurrentDomain.Evidence)
                , appDomainSetup
                , new PermissionSet(PermissionState.Unrestricted));

            return domain;
        }

        private static Assembly AppDomain_AssemblyResolve(object sender, ResolveEventArgs args)
        {
            try
            {
                Assembly assembly = Assembly.Load(args.Name);
                if (assembly != null)
                    return assembly;
            }
            catch (System.Exception /* e */)
            {
            }

            return null;
        }

    }
}
