﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Globalization;

using Microsoft.BizTalk.Management;

namespace BizTalkFactory.Management.Automation.Helper
{
    public static class BtsHandlerHelper
    {
        public const string HandlerNameTemplate = "{0} {1} Handler ({2})";

        public static string ConstructHandlerName(BtsReceiveHandler receiveHandler)
        {
            return ConstructHandlerNameInternal(receiveHandler.AdapterName,
                receiveHandler.Direction.ToString(),
                receiveHandler.HostName);
        }

        public static string ConstructHandlerName(BtsSendHandler sendHandler)
        {
            return ConstructHandlerNameInternal(sendHandler.AdapterName,
               sendHandler.Direction.ToString(),
               sendHandler.HostName);
        }

        private static string ConstructHandlerNameInternal(string adapterName, string direction, string hostName)
        {
            return String.Format(CultureInfo.InvariantCulture,
               HandlerNameTemplate,
               adapterName,
               direction,
               hostName);
        }

        public static BtsReceiveHandler FindReceiveHandler(BtsCatalog catalog, string hostName, string transportType)
        {
            BtsReceiveHandler receiveHandler = null;

            try
            {
                ReceiveHandler.StaticScope = ManagementScopeHelper.GetScope(
                    typeof(ReceiveHandler)
                    , catalog.Instance
                    , catalog.Database
                    );

                foreach (ReceiveHandler handler in ReceiveHandler.GetInstances())
                    if ((String.Compare(handler.HostName, hostName, StringComparison.InvariantCultureIgnoreCase) == 0) &&
                        (String.Compare(handler.AdapterName, transportType, StringComparison.InvariantCultureIgnoreCase) == 0))
                    {
                        receiveHandler = BtsReceiveHandler.FromItem(catalog, handler);
                        break;
                    }
            }
            finally
            {
                ReceiveHandler.StaticScope = null;
            }

            return receiveHandler;
        }

        public static BtsSendHandler FindSendHandler(BtsCatalog catalog, string hostName, string transportType)
        {
            BtsSendHandler sendHandler = null;

            try
            {
                SendHandler2.StaticScope = ManagementScopeHelper.GetScope(
                    typeof(SendHandler2)
                    , catalog.Instance
                    , catalog.Database
                    );

                foreach (SendHandler2 handler in SendHandler2.GetInstances())
                    if ((String.Compare(handler.HostName, hostName, StringComparison.InvariantCultureIgnoreCase) == 0) &&
                        (String.Compare(handler.AdapterName, transportType, StringComparison.InvariantCultureIgnoreCase) == 0))
                    {
                        sendHandler = BtsSendHandler.FromItem(catalog, handler);
                        break;
                    }
            }
            finally
            {
                SendHandler2.StaticScope = null;
            }

            return sendHandler;
        }
    }
}
