﻿using System;
using System.IO;
using System.Reflection;

namespace BizTalkFactory.Management.Automation
{
    public class ManagedAssemblyHelper : MarshalByRefObject
    {
        public bool IsManagedAssembly(string path)
        {
            try
            {
                Assembly.Load(GetRawFileContents(path));
                return true;
            }
            catch (BadImageFormatException /* e */)
            {
                return false;
            }
        }

        public bool IsBizTalkAssembly(string path)
        {
            try
            {
                Assembly.Load(GetRawFileContents(path));

                Assembly[] assemblies = AppDomain.CurrentDomain.GetAssemblies();
                foreach (Assembly assembly in assemblies)
                {
                    bool hasRef = false;

                    // check Microsoft.XLANGs.BaseTypes reference

                    foreach (AssemblyName reference in assembly.GetReferencedAssemblies())
                        if (reference.Name == "Microsoft.XLANGs.BaseTypes")
                        { hasRef = true; break; }

                    if (!hasRef)
                        continue;

                    // check for Microsoft.XLANGs.BaseTypes.BizTalkAssemblyAttribute

                    object[] attributes = assembly.GetCustomAttributes(false);
                    foreach (object attribute in attributes)
                        if (attribute.GetType().FullName == "Microsoft.XLANGs.BaseTypes.BizTalkAssemblyAttribute")
                            return true;
                }

                return false;
            }
            catch (BadImageFormatException /* e */)
            {
                return false;
            }
        }

        private byte[] GetRawFileContents(string path)
        {
            using (System.IO.FileStream stream = new FileStream(path, FileMode.Open, FileAccess.Read))
            {
                byte[] bytes = new byte[stream.Length];
                stream.Read(bytes, 0, bytes.Length);
                return bytes;
            }
        }
    }
}
