﻿using System;
using System.IO;
using System.Diagnostics;

// TODO: handle timeout in process execution
// TODO: handle standard error/output log

namespace BizTalkFactory.Management.Automation.Helper
{
    public enum MsiOptions
    {
        Quiet,
        Passive,
        Basic,
        Reduced,
        Full,
    }

    public sealed class MsiHelper
    {
        public static void MsiExecUninst(Guid identifier)
        {
            MsiExecUninst(identifier, MsiOptions.Passive);
        }

        public static void MsiExecUninst(Guid identifier, MsiOptions options)
        {
            MsiExecUninst(identifier, options, null);
        }
        
        public static void MsiExecUninst(Guid identifier, MsiOptions options, string logfile)
        {
            Process process = new Process();

            process.StartInfo = new ProcessStartInfo();
            process.StartInfo.CreateNoWindow = true;
            process.StartInfo.UseShellExecute = false;
            process.StartInfo.ErrorDialog = false;
            process.StartInfo.FileName = "msiexec.exe";
            process.StartInfo.Arguments = String.Format("/x{0:b} ", identifier);

            if (options == MsiOptions.Quiet) process.StartInfo.Arguments += "/quiet ";
            else if (options == MsiOptions.Passive) process.StartInfo.Arguments += "/passive ";
            else if (options == MsiOptions.Basic) process.StartInfo.Arguments += "/qb ";
            else if (options == MsiOptions.Reduced) process.StartInfo.Arguments += "/qr ";
            else if (options == MsiOptions.Full) process.StartInfo.Arguments += "/qf ";

            if (!String.IsNullOrEmpty(logfile))
                process.StartInfo.Arguments += String.Format("/l* \"{0}\" ", logfile);

            if (!process.Start())
                throw new BtsException(
                    String.Format("{0}\r\n\r\n{1} {2}"
                    , "Unable to start Windows Installer process."
                    , process.StartInfo.FileName
                    , process.StartInfo.Arguments));

            process.WaitForExit(0);
        }
    }
}
