using System;
using System.Collections.Generic;
using System.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal abstract class BizTalkObject
    {
        protected object item_;
        protected bool container_;
    
        protected internal BizTalkObject(object item, bool container)
        {
            item_ = item;
            container_ = container;
        }

        protected internal BizTalkObject(object item)
            : this(item, false)
        {
        }

        #region Attributes

        /// <summary>
        /// Gets the drive that is being used by the current operation.
        /// </summary>
        internal PSDriveInfo PSDriveInfo;

        #endregion

        #region BiztalkObject Overrides

        public virtual object Item
        {
            get { return item_; }
        }

        public virtual bool IsContainer
        {
            get { return container_; }
        }

        public abstract string Name { get; }

        public virtual bool ItemExists(string name)
        {
            BizTalkObject[] objects = GetChildItems(false);
            foreach (BizTalkObject item in objects)
                if (String.Compare(item.Name, name, StringComparison.InvariantCultureIgnoreCase) == 0)
                    return true;

            return false;
        }

        public virtual BizTalkObject GetItem(string name)
        {
            BizTalkObject[] objects = GetChildItems(false);
            foreach (BizTalkObject item in objects)
                if (String.Compare(item.Name, name, StringComparison.InvariantCultureIgnoreCase) == 0)
                    return item;

            throw new ArgumentException("Unable to find the specified item");
        }

        public virtual BizTalkObject GetItem(string name, object dynamicParameters)
        {
            return GetItem(name);
        }

        public virtual object NewItemDynamicParameters { get { return null; } }
        public virtual object GetItemDynamicParameters { get { return null; } }

        public virtual BizTalkObject[] GetChildItems(bool recurse)
        {
            if (!IsContainer) return new BizTalkObject[] { };
            throw new NotImplementedException();
        }

        #endregion

        public virtual BizTalkObject[] GetChildItems()
        {
            return GetChildItems(false);
        }

        public virtual BizTalkObject NewItem(string name)
        {
            return NewItem(name, String.Empty);
        }

        public virtual BizTalkObject NewItem(string name, string itemType)
        {
            return NewItem(name, itemType, null);
        }

        public virtual BizTalkObject NewItem(string name, string itemType, object parameters)
        {
            if (String.IsNullOrEmpty(itemType))
                return NewItem(name, parameters);

            throw new NotSupportedException();
        }

        public virtual BizTalkObject NewItem(string name, object parameters)
        {
            throw new NotSupportedException();
        }

        public virtual void RemoveItem(bool recurse)
        {
            throw new NotSupportedException();
        }

        public virtual void SetPropertyValue(PSPropertyInfo propertyInfo)
        {
            throw new NotSupportedException();
        }
    }
}
