﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Management.Automation;
using System.Globalization;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Add", "ApplicationReference", DefaultParameterSetName = "PathParameterSet")]
    public class AddApplicationReferenceCommand : BizTalkPathAndObjectCmdlet
    {
        private const string ERROR_REFERENCE_ALREADY_EXISTS = "Cannot add reference to application '{0}'. Reference already exists.";

        private BtsApplication[] references_ = null;

        [Parameter(Mandatory = true, Position = 1), ApplicationTransformation]
        public BtsApplication[] References
        {
            get { return references_; }
            set { references_ = value; }
        }

        protected override bool ValidateBtsType(object btsObject)
        {
            return btsObject is BtsApplication;
        }

        protected override void ProcessItem(object btsObject)
        {
            try
            {
                BtsApplication btsApplication = btsObject as BtsApplication;
                RegisterCatalog(btsApplication.Catalog);

                foreach (BtsApplication reference in references_)
                {
                    if (btsApplication.References.Contains(reference))
                    {
                        HandleAlreadyExistsError(reference.Name);
                        continue;
                    }

                    btsApplication.AddReference(reference);
                }

            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidOperation, btsObject));
            }
        }

        protected override void EndProcessing()
        {
            SaveChanges();
        }

        private void HandleAlreadyExistsError(string referenceApplicationName)
        {
            ErrorDetails errorDetails = new ErrorDetails(String.Format(CultureInfo.InvariantCulture, ERROR_REFERENCE_ALREADY_EXISTS, referenceApplicationName));
            ErrorRecord errorRecord = new ErrorRecord(new ArgumentException(), "0", ErrorCategory.InvalidArgument, referenceApplicationName);
            errorRecord.ErrorDetails = errorDetails;
            WriteError(errorRecord);
        }
    }
}
