﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Management.Automation;
using System.IO;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Add", "ApplicationResource", DefaultParameterSetName = "PathParameterSet")]
    public class AddApplicationResourceCommand : BizTalkPathAndObjectCmdlet
    {
        private string type = null;
        private bool overwrite = false;
        private FileInfo[] resourcePath = null;

        [Parameter(Position = 1, Mandatory = true, ValueFromPipeline = true ), FileInfoTransformation]
        [ValidateNotNullOrEmpty]
        public FileInfo[] ResourcePath
        {
            get { return resourcePath; }
            set { resourcePath = value; }
        }

        [Parameter(Position = 2)]
        public string Type
        {
            get { return type; }
            set { type = value; }
        }

        [Parameter(Position = 3)]
        public SwitchParameter Overwrite
        {
            get { return overwrite; }
            set { overwrite = value; }
        }

        public AddApplicationResourceCommand() : base(true)
        {}

        protected override bool ValidateBtsType(object btsObject)
        {
            return btsObject is BtsApplication;
        }

        protected override void ProcessItem(object btsObject)
        {
            try
            {
                BtsApplication btsApplication = btsObject as BtsApplication;

                RegisterCatalog(btsApplication.Catalog);
                foreach (FileInfo sourceFileInfo in resourcePath)
                {
                    if (String.IsNullOrEmpty(type))
                    {
                        btsApplication.AddNewResource(sourceFileInfo.FullName, overwrite);
                    }
                    else
                    {
                        btsApplication.AddNewResource(sourceFileInfo.FullName, type, overwrite);
                    }
                }
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidOperation, btsObject));
            }
        }

        protected override void EndProcessing()
        {
            SaveChanges();
        }
    }
}
