using System.Collections.Generic;
using System.Management.Automation;
using System.Collections.ObjectModel;
using System.Collections;
using System;
using BizTalkFactory.Management.Automation;
using System.Diagnostics;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    public class BizTalkCmdlet : System.Management.Automation.PSCmdlet
    {        
        protected List<BtsCatalog> catalogs_ = new List<BtsCatalog>();
        private Collection<string> resolvedPaths_ = null;

        protected virtual void RegisterCatalog(BtsCatalog catalog)
        {
            if (!catalogs_.Contains(catalog))
            {
                catalogs_.Add(catalog);
            }
        }

        protected virtual void SaveChanges()
        {
            foreach (BtsCatalog catalog in catalogs_)
            {
                catalog.SaveChanges();
                catalog.Refresh();
            }
        }
        
        protected virtual PSDriveInfo GetDrive(string path)
        {
            ProviderInfo providerInfo = null;

            return PathUtil.GetDrive(SessionState, path, out providerInfo, out resolvedPaths_);
        }

        protected virtual object[] GetItems(string path)
        {
            BizTalkDriveInfo driveInfo = GetDrive(path) as BizTalkDriveInfo;

            if (driveInfo == null)
            {
                return null;
            }

            return PathUtil.GetItems(driveInfo, resolvedPaths_);
        }

        #region Implementation Helpers

        protected static ErrorRecord CreateErrorRecord(ErrorCategory errorCategory, string format, params object[] args)
        {
            return CreateErrorRecord(errorCategory, "0", null, format, args);
        }

        protected static ErrorRecord CreateErrorRecord(ErrorCategory errorCategory, string errorId, object targetObject, string format, params object[] args)
        {
            string message = String.Format(format, args);

            Exception exception = new ArgumentException(message);
            if (errorCategory == ErrorCategory.InvalidArgument)
                exception = new ArgumentException(message);
            else if (errorCategory == ErrorCategory.InvalidOperation)
                exception = new ApplicationException(message);

            return new ErrorRecord(exception, errorId, errorCategory, targetObject);
        }

        #endregion
    }
}
