﻿using System;
using System.Collections.Generic;
using System.Management.Automation;
using System.Text;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    public class BizTalkPathAndObjectCmdlet : BizTalkPathCmdlet
    {
        private const string VALIDATE_SINGLE_OBJECT_ERROR = "You can only use a object as input parameter at a time.";

        protected object object_ = null;

        public BizTalkPathAndObjectCmdlet()
        { }

        public BizTalkPathAndObjectCmdlet(bool singlePathOnly)
            : base(singlePathOnly)
        { }

        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, ParameterSetName="ObjectParameterSet")]
        [ValidateNotNullOrEmpty]
        public object InputObject
        {
            get { return object_; }
            set
            {
                object_ = value;
            }
        }

        protected override void ProcessRecord()
        {
            if (paths_.Length > 0)
            {
                base.ProcessRecord();
            }
            else
            {
                object btsObject = RemovePSObject(object_);

                if (!ValidateBtsType(btsObject))
                {
                    WriteError(new ErrorRecord(new ArgumentException(), "0", ErrorCategory.InvalidArgument, object_));
                }

                ProcessItem(btsObject);
            }
        }

        protected object RemovePSObject(object tryObject)
        {
            if (tryObject is PSObject)
            {
                return (tryObject as PSObject).BaseObject;
            }

            return tryObject;
        }
    }
}
