using System.Collections.Generic;
using System.Management.Automation;
using System.Collections.ObjectModel;
using System.Collections;
using System;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    public class BizTalkPathCmdlet : BizTalkCmdlet
    {
        protected string[] paths_ = new string[] { };

        private bool singlePathOnly_ = false;
        private string singlePath_ = null;
                
        protected string SinglePath
        {
            get { return singlePath_; }
        }

        public BizTalkPathCmdlet()
        { }

        public BizTalkPathCmdlet(bool singlePathOnly)
        {
            this.singlePathOnly_ = singlePathOnly;
        }

        protected bool SinglePathOnly
        {
            get
            {
                return this.singlePathOnly_;
            }
        }

        [Parameter(Position = 0, Mandatory = true, ValueFromPipeline = true, ParameterSetName = "PathParameterSet")]
        [Alias(new string[] { "PSPath" })]
        [ValidateNotNullOrEmpty]
        public string[] Path
        {
            get { return paths_; }
            set
            {
                paths_ = value;
                if (singlePathOnly_)
                {
                    ValidateSinglePath(paths_);
                    singlePath_ = paths_[0];
                }
            }
        }

        protected override void ProcessRecord()
        {
            foreach (string path in paths_)
            {
                if (singlePathOnly_)
                {
                    ValidateSinglePath(path);
                }

                object[] btsObjects = GetItems(path);
                foreach (object btsObject in btsObjects)
                {
                    if (!ValidateBtsType(btsObject))
                    {
                        WriteError(CreateErrorRecord(ErrorCategory.InvalidType, Resources.BizTalkMshEx_InvalidObjectType, path, btsObject.GetType()));
                        continue;
                    }

                    ProcessItem(btsObject);
                }
            }
        }

        protected void ValidateSinglePath(string[] paths)
        {
            if (paths != null)
            {
                if (paths.Length != 1)
                {
                    ThrowTerminatingError(
                        new ErrorRecord(
                            new ArgumentException(Resources.BizTalkMshEx_MultipleContainersNotSupported), "", ErrorCategory.InvalidArgument, paths));
                }
            }
        }

        protected void ValidateSinglePath(string path)
        {
            ProviderInfo providerInfo = null;

            if (this.SessionState.Path.GetResolvedProviderPathFromPSPath(path, out providerInfo).Count > 1)
            {
                ThrowTerminatingError(new ErrorRecord(new ArgumentException(Resources.BizTalkMshEx_MultipleContainersNotSupported), "", ErrorCategory.InvalidArgument, path));
            }
        }

        protected virtual bool ValidateBtsType(object btsObject)
        { throw new ApplicationException(); }

        protected virtual void ProcessItem(object btsObject)
        { }
    }
}
