﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Management.Automation;

using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    public class BizTalkPolicyCmdlet : BizTalkPathAndObjectCmdlet
    {
        public BizTalkPolicyCmdlet() : base(true)
        { }

        // This cmdlet only supports a single path as input parameter because only
        // one destination parameter can be provided. 
        // Multiple paths would overwrite the package file for each path which 
        // doesn't make sense.

        private string version_ = String.Empty;

        [Parameter]
        public string Version
        {
            get { return version_; }
            set { version_ = value; }
        }

        protected override bool ValidateBtsType(object btsObject)
        {
            return btsObject is BtsPolicy;
        }

        protected override void ProcessRecord()
        {
            // if no -InputObject or -Version arguments have been specified
            // we perform the default processing 

            if (paths_.Length == 0)
                base.ProcessRecord();
                
            else if (String.IsNullOrEmpty(version_))
                base.ProcessRecord();

            // otherwize, we need to either handle retrieving the specified
            // policy (with matching version number) or the most appropriate
            // policy object as handled by the Get-Item CmdLet.

            else
            {
                ValidateSinglePath(paths_);

                string path = paths_[0];

                Collection<String> c_strings = PathUtil.ResolvePath(SessionState, path);
                if (c_strings.Count > 0)
                    path = c_strings[0];

                string parent = PathUtil.GetParentPath(path);
                string name = PathUtil.GetChildName(path);

                object btsObject = null;

                BizTalkDriveInfo driveInfo = (GetDrive(parent) as BizTalkDriveInfo);
                BizTalkObject[] items = driveInfo.BizTalkProvider.GetChildItemsInternal(parent, false);

                foreach (BizTalkObject item in items)
                {
                    if (!ValidateBtsType(item.Item))
                        ThrowTerminatingError(
                            CreateErrorRecord(
                              ErrorCategory.InvalidType
                            , Resources.BizTalkMshEx_InvalidObjectType
                            , path
                            , item.Item.GetType()));

                    BtsPolicy policy = (item.Item as BtsPolicy);
                    if (BtsPolicy.GetVersion(policy) == version_)
                    {
                        btsObject = policy;
                        break;
                    }
                }

                if (btsObject == null)
                    ThrowTerminatingError(
                        CreateErrorRecord(
                            ErrorCategory.InvalidArgument
                            , Resources.BizTalkMshEx_PolicyNotFound
                            , name));

                ProcessItem(btsObject);
            }
        }
    }
}
