using System;
using System.Collections.ObjectModel;
using System.Management.Automation;
using System.Diagnostics;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Export", "Application", DefaultParameterSetName = "PathParameterSet")]
    public class ExportApplicationCommand : BizTalkPathAndObjectCmdlet
    {
        // This cmdlet only supports a single path as input parameter because only
        // one package parameter can be provided. 
        // Multiple paths would overwrite the package file for each path which 
        // doesn't make sense.

        private string package_ = String.Empty;
        private object resourcespec_ = null;
        private bool include_party_bindings_ = false;

        [Parameter(Position = 1, Mandatory = true)]
        [ValidateNotNullOrEmpty]
        public string Package
        {
            get { return package_; }
            set { package_ = value; }
        }

        [Parameter(Position = 2)]
        public object ResourceSpec
        {
            get { return resourcespec_; }
            set { resourcespec_ = value; }
        }

        [Parameter(Position = 3)]
        public SwitchParameter IncludeGlobalPartyBinding
        {
            get { return include_party_bindings_; }
            set { include_party_bindings_ = value; }
        }

        public ExportApplicationCommand() : base(true)
        {}

        protected override bool ValidateBtsType(object btsObject)
        {
            return btsObject is BtsApplication;
        }

        protected override void ProcessItem(object btsObject)
        {
            object spec = RemovePSObject(resourcespec_);

            try
            {
                // Export Application MSI Package
                BtsApplication btsApplication = btsObject as BtsApplication;

                if (spec == null)
                    btsApplication.Export(package_, include_party_bindings_);

                else if (spec is System.Xml.XmlDocument)
                    btsApplication.Export(package_, (spec as System.Xml.XmlDocument), include_party_bindings_);

                else if (spec is String)
                    btsApplication.Export(package_, (spec as String), include_party_bindings_);

                else
                    throw new ArgumentException(Resources.BizTalkMshEx_InvalidResourceSpec);
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidArgument, btsObject));
            }
        }
    }
}
