using System;
using System.Collections.ObjectModel;
using System.Management.Automation;
using System.Diagnostics;
using System.Globalization;

using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Get", "TrackedMessageInstance")]
    public class GetTrackedMessageInstanceCommand : BizTalkCmdlet
    {
        private Guid messageInstanceID_ = Guid.Empty;

        [Parameter(Mandatory = true, Position = 0, ValueFromRemainingArguments = true)]
        public Guid MessageInstanceID
        {
            get { return messageInstanceID_; }
            set { messageInstanceID_ = value; }
        }

        protected override void ProcessRecord()
        {
            PSDriveInfo driveInfo = this.GetDrive(".");

            try
            {
                BizTalkDriveInfo drive = (driveInfo as BizTalkDriveInfo);
                if (drive == null)
                    HandleInvalidDriveError(driveInfo);

                WriteObject(
                    BtsTrackedMessageInstance.GetInstance(
                      drive.Catalog.Item as BtsCatalog
                    , messageInstanceID_)
                    );
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidOperation, driveInfo));
            }
        }

        private void HandleInvalidDriveError(PSDriveInfo driveInfo)
        {
            ErrorDetails errorDetails = new ErrorDetails(String.Format(CultureInfo.InvariantCulture, Resources.BizTalkMshEx_InvalidDrive, "BizTalk", driveInfo.Name));
            ErrorRecord errorRecord = new ErrorRecord(new ArgumentException(), "0", ErrorCategory.InvalidArgument, driveInfo.Name);
            errorRecord.ErrorDetails = errorDetails;
            WriteError(errorRecord);
        }

    }
}
