using System;
using System.Collections.ObjectModel;
using System.Management.Automation;
using System.IO;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Import", "Application", DefaultParameterSetName = "PathParameterSet")]
    public class ImportApplicationCommand : BizTalkPathAndObjectCmdlet
    {
        private FileInfo[] packages_ = null;
        private string stagingEnvironment_ = null;
        private bool overwrite_ = false;
                
        [Parameter(Position = 1, Mandatory = true, ValueFromPipeline=true), FileInfoTransformation]
        [ValidateNotNullOrEmpty]
        public FileInfo[] Packages
        {
            get { return packages_; }
            set { packages_ = value; }
        }

        [Parameter(Position = 2)]
        public string StagingEnvironment
        {
            get { return stagingEnvironment_; }
            set { stagingEnvironment_ = value; }
        }

        [Parameter(Position = 3)]
        public SwitchParameter Overwrite
        {
            get { return overwrite_; }
            set { overwrite_ = value; }
        }

        public ImportApplicationCommand()
            : base(true)
        { }

        protected override bool ValidateBtsType(object btsObject)
        {
            // This cmdlet can be called from with whatever path you want.
            // It only uses the drive part of the path to get to the biztalk
            // group where the application will be imported.
            return true;
        }

        protected override void ProcessItem(object btsObject)
        {
            try
            {
                // We use Path base class property with GetDrive method to get drive.
                // This also means that the path can be anything it doesn't have to point to a 
                // drive only path like 'BizTalk:'
                // Import-Application -Path 'BizTalk:\Applications\MyApplication\Send Ports' -Packages D:\MyPackage.msi

                BizTalkDriveInfo bizTalkDriveInfo = GetDrive(SinglePath) as BizTalkDriveInfo;
                BtsCatalog btsCatalog = bizTalkDriveInfo.Catalog.Item as BtsCatalog;

                foreach (FileInfo package in packages_)
                {
                    if (String.IsNullOrEmpty(stagingEnvironment_))
                    {
                        btsCatalog.ImportApplication(null, package.FullName, overwrite_);
                    }
                    else
                    {
                        btsCatalog.ImportApplication(null, package.FullName, stagingEnvironment_, overwrite_);
                    }
                }
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidArgument, btsObject));
            }
        }
    }
}
