﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Management.Automation;
using System.Collections.ObjectModel;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Import", "Bindings", DefaultParameterSetName = "PathParameterSet")]
    public class ImportBindingsCommand : BizTalkPathAndObjectCmdlet
    {
        // This cmdlet only supports a single path as input parameter because only
        // one source (binding file) parameter can be provided. 
        // Multiple paths would allow for importing the same binding file different applications
        // which doesn't really make sense.

        private string source_ = null;
        private bool group_ = false;

        [Parameter(Position = 1, Mandatory = true)]
        [ValidateNotNullOrEmpty]
        public string Source
        {
            get { return source_; }
            set { source_ = value; }
        }

        [Parameter(Position = 2)]
        public SwitchParameter GroupLevel
        {
            get { return group_; }
            set { group_ = value; }
        }

        public ImportBindingsCommand()
            : base(true)
        { }

        protected override bool ValidateBtsType(object btsObject)
        {
            if (group_)
            {
                return true;
            }

            return (
                btsObject is BtsCatalog ||
                btsObject is BtsApplication);
        }

        protected override void ProcessItem(object btsObject)
        {
            try
            {
                if (group_)
                {
                    // When the group switch is provided we need to get the drive from the path 
                    // in order to know for which biztalk group we need to import bindings.
                    // We use SinglePath base class property with GetDrive method to get this information.
                    // This also means that if the group switch is provided the path can be anything
                    // it doesn't have to point to a drive only path like 'BizTalk:'
                    // Import-Bindings -Path 'BizTalk:\Applications\MyApplication\Send Ports' -GroupLevel -Source c:\bindings.xml

                    BizTalkDriveInfo bizTalkDriveInfo = GetDrive(SinglePath) as BizTalkDriveInfo;
                    BtsCatalog btsCatalog = bizTalkDriveInfo.Catalog.Item as BtsCatalog;
                    btsCatalog.ImportBinding(source_);
                }
                else
                {
                    if (btsObject is BtsCatalog)
                    {
                        // In this case the group switch is not provided but the path is pointing
                        // to a drive only like 'BizTalk:'
                        // Import-Bindings -Path 'BizTalk:' -Source c:\bindings.xml
                        BtsCatalog btsCatalog = btsObject as BtsCatalog;
                        btsCatalog.ImportBinding(source_);
                    }
                    else if (btsObject is BtsApplication)
                    {
                        BtsApplication btsApplication = btsObject as BtsApplication;
                        btsApplication.ImportBinding(source_);
                    }
                }
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidArgument, btsObject));
            }
        }
    }
}
