﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Management.Automation;
using System.Globalization;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Remove", "ApplicationReference", DefaultParameterSetName = "PathParameterSet")]
    public class RemoveApplicationReferenceCommand : BizTalkPathAndObjectCmdlet
    {
        private const string ERROR_REFERENCE_DOES_NOT_EXIST = "Cannot remove reference from application '{0}'. Reference to application '{1}' does not exist.";

        private BtsApplication[] references_ = null;

        [Parameter(Mandatory = true, Position = 1), ApplicationTransformation]
        public BtsApplication[] References
        {
            get { return references_; }
            set { references_ = value; }
        }

        protected override bool ValidateBtsType(object btsObject)
        {
            return btsObject is BtsApplication;
        }

        protected override void ProcessItem(object btsObject)
        {
            try
            {
                BtsApplication btsApplication = btsObject as BtsApplication;
                RegisterCatalog(btsApplication.Catalog);

                foreach (BtsApplication reference in references_)
                {
                    if (!btsApplication.References.Contains(reference))
                    {
                        HandleReferenceNotExistingError(btsApplication.Name, reference.Name);
                        continue;
                    }

                    btsApplication.RemoveReference(reference);
                }
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidOperation, btsObject));
            }
        }

        protected override void EndProcessing()
        {
            SaveChanges();
        }

        private void HandleReferenceNotExistingError(string applicationName, string referencedApplicationName)
        {
            ErrorDetails errorDetails = new ErrorDetails(String.Format(CultureInfo.InvariantCulture, ERROR_REFERENCE_DOES_NOT_EXIST, applicationName, referencedApplicationName));
            ErrorRecord errorRecord = new ErrorRecord(new ArgumentException(), "0", ErrorCategory.InvalidArgument, referencedApplicationName);
            errorRecord.ErrorDetails = errorDetails;
            WriteError(errorRecord);
        }
    }
}
