﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Management.Automation;
using System.Globalization;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Set", "DefaultApplication", DefaultParameterSetName = "PathParameterSet")]
    public class SetDefaultApplicationCommand : BizTalkPathAndObjectCmdlet
    {
        private const string ERROR_ALREADY_DEFAULT = "This application is already the default application.";

        public SetDefaultApplicationCommand()
            : base(true)
        { }

        protected override bool ValidateBtsType(object btsObject)
        {
            return btsObject is BtsApplication;
        }

        protected override void ProcessItem(object btsObject)
        {
            try
            {
                BtsApplication btsApplication = btsObject as BtsApplication;

                if (!btsApplication.IsDefaultApplication)
                {
                    RegisterCatalog(btsApplication.Catalog);
                    btsApplication.Catalog.SetDefaultApplication(btsApplication);
                }
                else
                {
                    HandleAlreadyDefaultError(btsApplication.Name);
                }
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidArgument, btsObject));
            }
        }

        protected override void EndProcessing()
        {
            SaveChanges();
        }

        private void HandleAlreadyDefaultError(string targetName)
        {
            ErrorDetails errorDetails = new ErrorDetails(String.Format(CultureInfo.InvariantCulture, ERROR_ALREADY_DEFAULT));
            ErrorRecord errorRecord = new ErrorRecord(new ArgumentException(), "0", ErrorCategory.InvalidArgument, targetName);
            errorRecord.ErrorDetails = errorDetails;
            WriteError(errorRecord);
        }
    }
}
