using System;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Start", "Application", DefaultParameterSetName = "PathParameterSet")]
    public class StartApplicationCommand : BizTalkPathAndObjectCmdlet
    {
        private BtsApplicationStartOption startOption_ =
            BtsApplicationStartOption.StartAll &~
            BtsApplicationStartOption.StartReferencedApplications;

        [Parameter(Position = 1)]
        public BtsApplicationStartOption StartOption
        {
            get { return startOption_; }
            set { startOption_ = value; }
        }

        protected override bool ValidateBtsType(object btsObject)
        {
            return btsObject is BtsApplication;
        }

        protected override void ProcessItem(object btsObject)
        {
            try
            {
                BtsApplication btsApplication = btsObject as BtsApplication;
                RegisterCatalog(btsApplication.Catalog);
                btsApplication.Start(startOption_);
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidOperation, btsObject));
            }
        }

        protected override void EndProcessing()
        {
            SaveChanges();
        }
    }
}
