using System;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions.Cdmlets
{
    [Cmdlet("Stop", "Application", DefaultParameterSetName = "PathParameterSet")]
    public class StopApplicationCommand : BizTalkPathAndObjectCmdlet
    {
        private BtsApplicationStopOption stopOption_ =
            BtsApplicationStopOption.StopAll &~
            BtsApplicationStopOption.StopReferencedApplications;
                
        [Parameter(Position = 1)]
        public BtsApplicationStopOption StopOption
        {
            get { return stopOption_; }
            set { stopOption_ = value; }
        }

        protected override bool ValidateBtsType(object btsObject)
        {
            return btsObject is BtsApplication;
        }

        protected override void ProcessItem(object btsObject)
        {
            try
            {
                BtsApplication btsApplication = btsObject as BtsApplication;
                RegisterCatalog(btsApplication.Catalog);
                btsApplication.Stop(StopOption);
            }
            catch (Exception e)
            {
                WriteError(new ErrorRecord(e, "0", ErrorCategory.InvalidOperation, btsObject));
            }
        }

        protected override void EndProcessing()
        {
            SaveChanges();
        }
    }
}
