﻿using System;
using System.Collections.Generic;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class Adapter : BizTalkObject
    {
        internal Adapter(object item)
            : base(item, true)
        {
            System.Diagnostics.Debug.Assert(item is BtsAdapter);
        }

        private new BtsAdapter Item
        {
            get { return (base.Item as BtsAdapter); }
        }

        public override string Name
        {
            get { return Item.Name; }
        }

        public override object NewItemDynamicParameters
        {
            get { return new NewHandlerDynamicParameters(); }
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            BtsCatalog btsCatalog = this.Item.Catalog;

            BtsReceiveHandlerCollection btsReceiveHandlerCollection = new BtsReceiveHandlerCollection(btsCatalog);
            BtsSendHandlerCollection btsSendHandlerCollection = new BtsSendHandlerCollection(btsCatalog);
            
            List <BizTalkObject> objects = new List<BizTalkObject>();

            foreach (BtsReceiveHandler btsReceiveHandler in btsReceiveHandlerCollection)
            {
                if (btsReceiveHandler.AdapterName.Equals(this.Item.Name, StringComparison.OrdinalIgnoreCase))
                {
                    objects.Add(new ReceiveHandler(btsReceiveHandler));
                }
            }

            foreach (BtsSendHandler btsSendHandler in btsSendHandlerCollection)
            {
                if (btsSendHandler.AdapterName.Equals(this.Item.Name, StringComparison.OrdinalIgnoreCase))
                {
                    objects.Add(new SendHandler(btsSendHandler));
                }
            }

            return objects.ToArray();
        }

        public override BizTalkObject NewItem(string name, object parameters)
        {
            System.Diagnostics.Debug.Assert(parameters != null);
            System.Diagnostics.Debug.Assert(parameters is NewHandlerDynamicParameters);

            NewHandlerDynamicParameters dynamicParams = (parameters as NewHandlerDynamicParameters);

            BtsHost host = Item.Catalog.Hosts[dynamicParams.HostName];
            BtsArtifact handler = null;

            switch (dynamicParams.Direction)
            {
                case BtsHandlerDirection.Receive:
                    handler = Item.AddNewReceiveHandler(host);
                    break;

                case BtsHandlerDirection.Send:
                    handler = Item.AddNewSendHandler(host, dynamicParams.CustomProps);
                    (handler as BtsSendHandler).SwitchHost(dynamicParams.HostName);
                    (handler as BtsSendHandler).Default = dynamicParams.Default;
                    break;
            }

            return GetItem(handler.Name);
        }

        public override void RemoveItem(bool recurse)
        {
            this.Item.Catalog.RemoveAdapter(this.Item);
        }
    }
}
