﻿using System;
using System.Collections.Generic;
using System.Text;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class AdaptersFolder : Folder
    {
        internal AdaptersFolder(BizTalkObject parent)
            : base(parent, new FolderContainer("Adapters"))
        {
        }

        public override object NewItemDynamicParameters
        {
            get { return new NewAdapterDynamicParameters(); }
        }

        public override BizTalkObject NewItem(string name, object parameters)
        {
            System.Diagnostics.Debug.Assert(parameters != null);
            System.Diagnostics.Debug.Assert(parameters is NewAdapterDynamicParameters);

            NewAdapterDynamicParameters dynamicParams = (parameters as NewAdapterDynamicParameters);

            string database = (PSDriveInfo as BizTalkDriveInfo).Database;
            string instance = (PSDriveInfo as BizTalkDriveInfo).Instance;

            BtsCatalog btsCatalog = BtsCatalog.Connect(instance, database);

            string transportType = dynamicParams.TransportType;
            string description = dynamicParams.Description ?? String.Empty;

            btsCatalog.AddNewAdapter(name, transportType, description);

            return GetItem(transportType);
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            string database = (PSDriveInfo as BizTalkDriveInfo).Database;
            string instance = (PSDriveInfo as BizTalkDriveInfo).Instance;

            BtsCatalog btsCatalog = BtsCatalog.Connect(instance, database);

            BtsAdapterCollection btsAdapterCollection = new BtsAdapterCollection(btsCatalog);

            List<BizTalkObject> objects = new List<BizTalkObject>();

            foreach (BtsAdapter adapter in btsAdapterCollection)
                objects.Add(new Adapter(adapter));

            return objects.ToArray();
        }
    }
}
