using System;
using System.Collections.Generic;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class Application : BizTalkObject
    {
        internal Application(object item)
            : base(item, true)
        {
            System.Diagnostics.Debug.Assert(item is BtsApplication);
        }

        private new BtsApplication Item
        {
            get { return (base.Item as BtsApplication); }
        }

        public override string Name
        {
            get { return Item.Name; }
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            List<BizTalkObject> objects = new List<BizTalkObject>();

            objects.Add(new BackReferencesFolder(this));
            objects.Add(new OrchestrationsFolder(this));
            objects.Add(new PoliciesFolder(this));
            objects.Add(new PipelinesFolder(this));
            objects.Add(new ReferencesFolder(this));
            objects.Add(new ReceiveLocationsFolder(this));
            objects.Add(new ReceivePortsFolder(this));
            objects.Add(new ResourcesFolder(this));
            objects.Add(new SchemasFolder(this));
            objects.Add(new SendPortGroupsFolder(this));
            objects.Add(new SendPortsFolder(this));

            return objects.ToArray();
        }

        public override void RemoveItem(bool recurse)
        {
            this.Item.Catalog.RemoveApplication(this.Item, recurse);
        }

        public override void SetPropertyValue(PSPropertyInfo propertyInfo)
        {
            if (!propertyInfo.IsSettable)
            {
                throw new ArgumentException("Property is not settable");
            }

            switch (propertyInfo.Name.ToLower())
            {
                case "name":
                    this.Item.SetName(propertyInfo.Value.ToString());
                    break;
                case "description":
                    this.Item.Description = propertyInfo.Value.ToString();
                    break;
            }

            this.Item.Catalog.SaveChanges();
        }
    }
}
