using System;
using System.Collections.Generic;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class ApplicationsFolder : Folder
    {
        internal ApplicationsFolder(BizTalkObject parent)
            : base(parent, new FolderContainer("Applications"))
        {
        }

        public override object NewItemDynamicParameters
        {
            get { return new NewApplicationDynamicParameters(); }
        }

        public override BizTalkObject NewItem(string name, object parameters)
        {
            string description = String.Empty;
            bool isDefault = false;
            BtsApplication[] references = new BtsApplication[] { };
            
            NewApplicationDynamicParameters dynamicParams = null;

            // Dynamic parameters are not mandatory for new application. Allow for providing additional data only.
            // If parameters are provided they should be of type 'NewApplicationDynamicParameters'.
            if (parameters != null)
            {
                System.Diagnostics.Debug.Assert(parameters is NewApplicationDynamicParameters);
                dynamicParams = (parameters as NewApplicationDynamicParameters);
                description = dynamicParams.Description;
                isDefault = dynamicParams.Default;
                references = dynamicParams.References;
            }
             
            string database = (PSDriveInfo as BizTalkDriveInfo).Database;
            string instance = (PSDriveInfo as BizTalkDriveInfo).Instance;

            BtsCatalog btsCatalog = BtsCatalog.Connect(instance, database);

            btsCatalog.AddNewApplication(name, description, isDefault, references);
            
            btsCatalog.SaveChanges();
            
            return GetItem(name);
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            string database = (PSDriveInfo as BizTalkDriveInfo).Database;
            string instance = (PSDriveInfo as BizTalkDriveInfo).Instance;

            BtsCatalog btsCatalog = BtsCatalog.Connect(instance, database);

            BtsApplicationCollection btsApplicationCollection = new BtsApplicationCollection(btsCatalog);

            List<BizTalkObject> objects = new List<BizTalkObject>();

            foreach (BtsApplication btsApplication in btsApplicationCollection)
            {
                objects.Add(new BizTalkFactory.PowerShell.Extensions.Application(btsApplication));
            }

            return objects.ToArray();
        }
    }
}
