using System;
using System.Collections.Generic;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class Catalog : BizTalkObject
    {
        private string root_;

        internal Catalog(object item, string root)
            : base(item, true)
        {
            System.Diagnostics.Debug.Assert(item is BtsCatalog);

            root_ = root;
        }

        private new BtsCatalog Item
        {
            get { return (base.Item as BtsCatalog); }
        }

        public override string Name
        {
            get { return root_; }
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            List<BizTalkObject> objects = new List<BizTalkObject>();
            objects.Add(new AllArtifactsFolder(this));
            objects.Add(new ApplicationsFolder(this));
            objects.Add(new PartiesFolder(this));
            objects.Add(new PlatformSettingsFolder(this));
            objects.Add(new HealthAndActivityFolder(this));
            return objects.ToArray();
        }

        public override void SetPropertyValue(System.Management.Automation.PSPropertyInfo propertyInfo)
        {
            switch (propertyInfo.Name.ToLower())
            {
                case "name":
                    this.Item.Name = propertyInfo.Value.ToString();
                    break;
            }

            this.Item.SaveChanges();
        }
    }
}
