using System;
using System.Collections.Generic;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class Host : BizTalkObject
    {
        internal Host(object item)
            : base(item)
        {
            System.Diagnostics.Debug.Assert(item is BtsHost);
        }

        private new BtsHost Item
        {
            get { return (base.Item as BtsHost); }
        }

        public override string Name
        {
            get { return Item.Name; }
        }

        public override void RemoveItem(bool recurse)
        {
            this.Item.Catalog.RemoveHost(this.Item);
        }

        public override void SetPropertyValue(PSPropertyInfo propertyInfo)
        {
            if (!propertyInfo.IsSettable)
            {
                throw new ArgumentException("Property is not settable");
            }

            switch (propertyInfo.Name.ToLower())
            {
                case "hosttracking":

                    bool hostTrackingValue = false;

                    if (!Boolean.TryParse(propertyInfo.Value.ToString(), out hostTrackingValue))
                    {
                        throw new ArgumentException("Invalid value.", "HostTracking");
                    }
                    this.Item.HostTracking = hostTrackingValue;
                    break;

                case "isdefault":

                    bool isDefaultValue = false;

                    if (!Boolean.TryParse(propertyInfo.Value.ToString(), out isDefaultValue))
                    {
                        throw new ArgumentException("Invalid value.", "IsDefault");
                    }

                    if (!isDefaultValue)
                    {
                        // Setting a host to default == false is not allowed. You can only set a host default to true.
                        // If you do so the other hosts automatically become NOT the default host.
                        // So SetPropertyValue for this property is only allowed if the parameter is true.

                        throw new ArgumentException("Only 'true' is allowed as parameter value. Cannot explicitly set default host to false. Set other host to default is true instead.", "IsDefault");
                    }

                    this.Item.IsDefault = isDefaultValue;
                    break;

                case "is32bitonly":

                    bool is32BitOnlyValue = false;

                    if (!Boolean.TryParse(propertyInfo.Value.ToString(), out is32BitOnlyValue))
                    {
                        throw new ArgumentException("Invalid value.", "Is32BitOnly");
                    }
                    this.Item.Is32BitOnly = is32BitOnlyValue;
                    break;
            }

            this.Item.Catalog.SaveChanges();
        }
    }
}
