using System;
using System.Collections.Generic;

using System.Management;
using System.Net;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class HostInstance : BizTalkObject
    {
        internal HostInstance(object item)
            : base(item)
        {
            System.Diagnostics.Debug.Assert(item is BtsHostInstance);
        }

        // Just a place holder property to be able to set credentials for a host instance
        // using 'Set-ItemProperty' CmdLet.
        public PSCredential Credential
        {
            set { ; }
        }

        private new BtsHostInstance Item
        {
            get { return (base.Item as BtsHostInstance); }
        }

        public override string Name
        {
            get { return Item.Name; }
        }

        public override void RemoveItem(bool recurse)
        {
            this.Item.Catalog.RemoveHostInstance(this.Item);
        }

        public override void SetPropertyValue(PSPropertyInfo propertyInfo)
        {
            if (!propertyInfo.IsSettable)
            {
                throw new ArgumentException("Property is not settable");
            }

            switch (propertyInfo.Name.ToLower())
            {
                case "isdisabled":
                    bool value = false; 
                    if (!Boolean.TryParse(propertyInfo.Value.ToString(), out value))
                    {
                        throw new ArgumentException("Invalid value.", "IsDisabled");
                    }
                    this.Item.IsDisabled = value;
                    break;

                case "credential":

                    PSCredential psCredential = ((PSObject)propertyInfo.Value).BaseObject as PSCredential;

                    if (psCredential == null)
                    {
                        throw new ArgumentException("Invalid value.", "Credential");
                    }

                    this.Item.Configure(psCredential.GetNetworkCredential());
                    
                    break;
            }
        }
    }
}
