using System;
using System.Collections.Generic;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class HostInstancesFolder : Folder
    {
        internal HostInstancesFolder(BizTalkObject parent)
            : base(parent, new FolderContainer("Host Instances"))
        {
        }
        
        public override object NewItemDynamicParameters
        {
            get { return new NewHostInstanceDynamicParameters(); }
        }

        public override BizTalkObject NewItem(string name, object parameters)
        {
            System.Diagnostics.Debug.Assert(parameters != null);
            System.Diagnostics.Debug.Assert(parameters is NewHostInstanceDynamicParameters);

            NewHostInstanceDynamicParameters dynamicParams = (parameters as NewHostInstanceDynamicParameters);

            string database = (PSDriveInfo as BizTalkDriveInfo).Database;
            string instance = (PSDriveInfo as BizTalkDriveInfo).Instance;

            BtsCatalog btsCatalog = BtsCatalog.Connect(instance, database);

            string runningServer = dynamicParams.RunningServer;
            if (String.IsNullOrEmpty(runningServer))
            {
                runningServer = System.Environment.MachineName;
            }
            
            PSCredential credentials = dynamicParams.Credentials;
            string hostName = dynamicParams.HostName;

            btsCatalog.AddNewHostInstance(hostName, runningServer, credentials.GetNetworkCredential());

            return GetItem(BtsHostInstance.GetNameFromHostName(hostName, runningServer));
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            string database = (PSDriveInfo as BizTalkDriveInfo).Database;
            string instance = (PSDriveInfo as BizTalkDriveInfo).Instance;

            BtsCatalog btsCatalog = BtsCatalog.Connect(instance, database);

            BtsHostInstanceCollection btsHostInstanceCollection = new BtsHostInstanceCollection(btsCatalog);

            List<BizTalkObject> objects = new List<BizTalkObject>();

            foreach (BtsHostInstance hostInstance in btsHostInstanceCollection)
                objects.Add(new HostInstance(hostInstance));

            return objects.ToArray();
        }
    }
}
