using System;
using System.Collections.Generic;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class HostsFolder : Folder
    {
        internal HostsFolder(BizTalkObject parent)
            : base(parent, new FolderContainer("Hosts"))
        {
        }

        public override object NewItemDynamicParameters
        {
            get { return new NewHostDynamicParameters(); }
        }

        public override BizTalkObject NewItem(string name, object parameters)
        {
            System.Diagnostics.Debug.Assert(parameters != null);
            System.Diagnostics.Debug.Assert(parameters is NewHostDynamicParameters);

            NewHostDynamicParameters dynamicParams = (parameters as NewHostDynamicParameters);

            string database = (PSDriveInfo as BizTalkDriveInfo).Database;
            string instance = (PSDriveInfo as BizTalkDriveInfo).Instance;

            BtsCatalog btsCatalog = BtsCatalog.Connect(instance, database);
                        
            btsCatalog.AddNewHost(name,
                ((BtsHostType)(int)dynamicParams.HostType),
                dynamicParams.NtGroupName,
                dynamicParams.AuthTrusted.ToBool());

            return GetItem(name);

        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            string database = (PSDriveInfo as BizTalkDriveInfo).Database;
            string instance = (PSDriveInfo as BizTalkDriveInfo).Instance;

            BtsCatalog btsCatalog = BtsCatalog.Connect(instance, database);

            BtsHostCollection btsHostCollection = new BtsHostCollection(btsCatalog);

            List<BizTalkObject> objects = new List<BizTalkObject>();

            foreach (BtsHost host in btsHostCollection)
                objects.Add(new Host(host));

            return objects.ToArray();
        }
    }
}
