﻿using System;
using System.Collections.Generic;
using System.Text;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class PoliciesFolder : Folder
    {
        internal PoliciesFolder(BizTalkObject parent)
            : base (parent, new FolderContainer("Policies"))
        {
        }

        public override object GetItemDynamicParameters
        {
            get { return new GetPolicyDynamicParameters(); }
        }

        public override BizTalkObject GetItem(string name, object dynamicParameters)
        {
            GetPolicyDynamicParameters parameters = (dynamicParameters as GetPolicyDynamicParameters);

            // retrieve all policies with the specified name (possibly, several versions exist)

            List<BtsPolicy> btsPolicies = new List<BtsPolicy>(1);

            BtsApplication btsApplication = this.Parent.Item as BtsApplication;
            foreach (BtsPolicy btsPolicy in btsApplication.Policies)
            {
                if (String.Compare(btsPolicy.Name, name, StringComparison.InvariantCultureIgnoreCase) == 0)
                    btsPolicies.Add(btsPolicy);
            }

            // if the version is not specified, retrieve the highest version available

            if ((parameters == null) || String.IsNullOrEmpty(parameters.Version))
            {
                btsPolicies.Sort(BtsPolicy.Comparer);

                // first, retrieve the highest (deployed) version available

                for (int index = btsPolicies.Count - 1; index >= 0; index--)
                    if (btsPolicies[index].Deployed)
                        return new BizTalkFactory.PowerShell.Extensions.Policy(btsPolicies[index]);

                // if none are deployed, then return the highest (published) version available

                for (int index = btsPolicies.Count - 1; index >= 0; index--)
                    if (btsPolicies[index].Published)
                        return new BizTalkFactory.PowerShell.Extensions.Policy(btsPolicies[index]);
            }

            // otherwize, retrieve the policy with the matching version number

            else
            {
                foreach (BtsPolicy btsPolicy in btsPolicies)
                    if (BtsPolicy.GetVersion(btsPolicy) == parameters.Version)
                        return new BizTalkFactory.PowerShell.Extensions.Policy(btsPolicy);

                throw new BtsException(String.Format(Resources.BizTalkMshEx_PolicyVerNotFound, name, parameters.Version));
            }

            System.Diagnostics.Debug.Assert(false);
            return null;
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            List<BizTalkObject> objects = new List<BizTalkObject>();

            if (this.Parent.Item is BtsApplication)
            {
                BtsApplication btsApplication = this.Parent.Item as BtsApplication;
                foreach (BtsPolicy btsPolicy in btsApplication.Policies)
                    objects.Add(new BizTalkFactory.PowerShell.Extensions.Policy(btsPolicy));
            }

            else if (this.Parent.Item is BtsCatalog)
            {
                BtsCatalog btsCatalog = this.Parent.Item as BtsCatalog;
                foreach (BtsPolicy btsPolicy in btsCatalog.Policies)
                    objects.Add(new BizTalkFactory.PowerShell.Extensions.Policy(btsPolicy));
            }

            return objects.ToArray();
        }

    }
}
