﻿using System;
using System.Collections.Generic;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class ReceivePort : BizTalkObject
    {
        internal ReceivePort(object item)
            : base(item, true)
        {
            System.Diagnostics.Debug.Assert(item is BtsReceivePort);
        }

        private new BtsReceivePort Item
        {
            get { return (base.Item as BtsReceivePort); }
        }

        public override string Name
        {
            get { return Item.Name; }
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            List<BizTalkObject> objects = new List<BizTalkObject>();

            foreach (BtsReceiveLocation btsReceiveLocation in this.Item.ReceiveLocations)
            {
                objects.Add(new BizTalkFactory.PowerShell.Extensions.ReceiveLocation(btsReceiveLocation));
            }

            return objects.ToArray();
        }

        public override void RemoveItem(bool recurse)
        {
            BtsCatalog btsCatalog = this.Item.Catalog;
            this.Item.Application.RemoveReceivePort(this.Item);
            btsCatalog.SaveChanges();
        }

        public override void SetPropertyValue(PSPropertyInfo propertyInfo)
        {
            if (!propertyInfo.IsSettable)
            {
                throw new ArgumentException("Property is not settable");
            }

            switch (propertyInfo.Name.ToLower())
            {
                case "name":
                    this.Item.SetName(propertyInfo.Value.ToString());
                    break;
                case "description":
                    this.Item.Description = propertyInfo.Value.ToString();
                    break;
            }

            this.Item.Catalog.SaveChanges();
        }
    }
}
