using System;
using System.Collections.Generic;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class Resource : BizTalkObject
    {
        internal Resource(object item)
            : base(item)
        {
            System.Diagnostics.Debug.Assert(item is BtsResource);
        }

        public new BtsResource Item
        {
            get { return item_ as BtsResource; }
        }

        public override string Name
        {
            get { return Item.DisplayName; }
        }

        public override void RemoveItem(bool recurse)
        {
            BtsCatalog btsCatalog = this.Item.Catalog;
            this.Item.Application.RemoveResource(this.Item);
            btsCatalog.SaveChanges();
        }

        public override void SetPropertyValue(PSPropertyInfo propertyInfo)
        {
            if (!propertyInfo.IsSettable)
            {
                throw new ArgumentException("Property is not settable");
            }

            switch (propertyInfo.Name.ToLower())
            {
                case "gaconadd":
                    this.Item.GacOnAdd = Boolean.Parse(propertyInfo.Value.ToString());
                    break;
                case "gaconinstall":
                    this.Item.GacOnInstall = Boolean.Parse(propertyInfo.Value.ToString());
                    break;
                case "gaconimport":
                    this.Item.GacOnImport = Boolean.Parse(propertyInfo.Value.ToString());
                    break;
                case "regsvcs":
                    this.Item.Regsvcs = Boolean.Parse(propertyInfo.Value.ToString());
                    break;
                case "regasm":
                    this.Item.Regasm = Boolean.Parse(propertyInfo.Value.ToString());
                    break;
                case "regsvr32":
                    this.Item.RegSvr32 = Boolean.Parse(propertyInfo.Value.ToString());
                    break;

                case "destinationlocation":
                    this.Item.DestinationLocation = propertyInfo.Value.ToString();
                    break;
                case "targetenvironment":
                    this.Item.TargetEnvironment = propertyInfo.Value.ToString();
                    break;
            }

            this.Item.Catalog.SaveChanges();
        }
    }
}
