using System;
using System.Collections.Generic;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class ResourcesFolder : Folder
    {
        internal ResourcesFolder(BizTalkObject parent)
            : base(parent, new FolderContainer("Resources"))
        {
        }

        public override object NewItemDynamicParameters
        {
            get { return new NewResourceDynamicParameters(); }
        }

        public override BizTalkObject NewItem(string name, string itemType, object parameters)
        {
            System.Diagnostics.Debug.Assert(parameters != null);
            System.Diagnostics.Debug.Assert(parameters is NewResourceDynamicParameters);

            NewResourceDynamicParameters dynamicParams = (parameters as NewResourceDynamicParameters);

            BtsApplication btsApplication = (Parent.Item as BtsApplication);

            BtsResource btsResource = null;

            if (String.IsNullOrEmpty(itemType))
                btsResource = btsApplication.AddNewResource(
                      dynamicParams.SourceLocation
                    , dynamicParams.Overwrite
                    , dynamicParams.GacOnAdd.IsPresent ? true : false
                    , dynamicParams.GacOnInstall.IsPresent ? true : false
                    , dynamicParams.GacOnImport.IsPresent ? true : false);
            else
                btsResource = btsApplication.AddNewResource(
                      dynamicParams.SourceLocation
                    , itemType
                    , dynamicParams.Overwrite
                    , dynamicParams.GacOnAdd.IsPresent ? true : false
                    , dynamicParams.GacOnInstall.IsPresent ? true : false
                    , dynamicParams.GacOnImport.IsPresent ? true : false);

            // add commonly used extra properties

            if (!String.IsNullOrEmpty(dynamicParams.DestinationLocation))
                btsResource.DestinationLocation = dynamicParams.DestinationLocation;
            if (!String.IsNullOrEmpty(dynamicParams.TargetEnvironment))
                btsResource.TargetEnvironment = dynamicParams.TargetEnvironment;
            if (!String.IsNullOrEmpty(dynamicParams.Arguments))
                btsResource.Arguments = dynamicParams.Arguments;

            if (dynamicParams.GacOnAdd.IsPresent)
                btsResource.GacOnAdd = dynamicParams.GacOnAdd.ToBool();
            if (dynamicParams.GacOnInstall.IsPresent)
                btsResource.GacOnInstall = dynamicParams.GacOnInstall.ToBool();
            if (dynamicParams.GacOnImport.IsPresent)
                btsResource.GacOnImport = dynamicParams.GacOnImport.ToBool();

            if (dynamicParams.Regasm.IsPresent)
                btsResource.Regasm = dynamicParams.Regasm.ToBool();
            if (dynamicParams.Regsvcs.IsPresent)
                btsResource.Regsvcs = dynamicParams.Regsvcs.ToBool();

            if (dynamicParams.RegSvr32.IsPresent)
                btsResource.RegSvr32 = dynamicParams.RegSvr32.ToBool();

            // return the resulting resource

            return new BizTalkFactory.PowerShell.Extensions.Resource(btsResource);
        }

        public override BizTalkObject[] GetChildItems(bool recurse)
        {
            List<BizTalkObject> objects = new List<BizTalkObject>();

            if (this.Parent.Item is BtsApplication)
            {
                BtsApplication btsApplication = this.Parent.Item as BtsApplication;
                foreach (BtsResource btsResource in btsApplication.Resources)
                    if (btsResource.ShowResource && (btsResource.ResourceType != "System.BizTalk:Rules"))
                        objects.Add(new BizTalkFactory.PowerShell.Extensions.Resource(btsResource));
            }

            else if (this.Parent.Item is BtsCatalog)
            {
                BtsCatalog btsCatalog = this.Parent.Item as BtsCatalog;
                foreach (BtsResource btsResource in btsCatalog.Resources)
                    if (btsResource.ShowResource && (btsResource.ResourceType != "System.BizTalk:Rules"))
                        objects.Add(new BizTalkFactory.PowerShell.Extensions.Resource(btsResource));
            }

            return objects.ToArray();
        }
    }
}
