﻿using System;
using System.Collections.Generic;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class SendHandler : BizTalkObject
    {
        internal SendHandler(object item)
            : base(item, false)
        {
            System.Diagnostics.Debug.Assert(item is BtsSendHandler);
        }

        private new BtsSendHandler Item
        {
            get { return (base.Item as BtsSendHandler); }
        }

        public override string Name
        {
            get { return Item.Name; }
        }

        public override void RemoveItem(bool recurse)
        {
            Item.Catalog.RemoveHandler(this.Item);
        }

        public override void SetPropertyValue(PSPropertyInfo propertyInfo)
        {
            if (!propertyInfo.IsSettable)
            {
                throw new ArgumentException("Property is not settable");
            }

            switch (propertyInfo.Name.ToLower())
            {
                case "default":
                    bool value = false;
                    if (!Boolean.TryParse(propertyInfo.Value.ToString(), out value))
                    {
                        throw new ArgumentException("Invalid value.", "Default");
                    }
                    this.Item.Default = value;
                    break;

                case "hostname":

                    string hostName = propertyInfo.Value.ToString();

                    if (hostName == null)
                    {
                        throw new ArgumentException("Invalid host name", "host");
                    }

                    this.Item.SwitchHost(hostName);

                    break;

                case "customprops":

                    string customProps = propertyInfo.Value.ToString();

                    if (customProps == null)
                    {
                        throw new ArgumentException("Invalid value for CustomProps", "customprops");
                    }

                    this.Item.CustomProps = customProps;

                    break;
            }
        }
    }
}