using System;
using System.Management.Automation;
using BizTalkFactory.Management.Automation;

namespace BizTalkFactory.PowerShell.Extensions
{
    internal class SendPort : BizTalkObject
    {
        internal SendPort(object item)
            : base(item)
        {
            System.Diagnostics.Debug.Assert(item is BtsSendPort);
        }

        private new BtsSendPort Item
        {
            get { return (base.Item as BtsSendPort); }
        }

        public override string Name
        {
            get { return Item.Name; }
        }

        public override void RemoveItem(bool recurse)
        {
            BtsCatalog btsCatalog = this.Item.Catalog;
            this.Item.Application.RemoveSendPort(this.Item);
            btsCatalog.SaveChanges();
        }

        public override void SetPropertyValue(PSPropertyInfo propertyInfo)
        {
            if (!propertyInfo.IsSettable)
            {
                throw new ArgumentException("Property is not settable");
            }

            switch (propertyInfo.Name.ToLower())
            {
                case "name":
                    this.Item.SetName(propertyInfo.Value.ToString());
                    break;
                case "description":
                    this.Item.Description = propertyInfo.Value.ToString();
                    break;
                case "primarytransportaddress":
                    this.Item.PrimaryTransport.Address = propertyInfo.Value.ToString();
                    break;
                case "secondarytransportaddress":
                    this.Item.SecondaryTransport.Address = propertyInfo.Value.ToString();
                    break;
            }

            this.Item.Catalog.SaveChanges();
        }
    }
}
