using System;
using System.ComponentModel;
using System.Management.Automation;
using System.Collections.ObjectModel;
using System.Management.Automation.Runspaces;
using System.Reflection;

namespace BizTalkFactory.PowerShell.Extensions
{
    [RunInstaller(true)]
    public class SnapIn : CustomPSSnapIn
    {
        private Collection<ProviderConfigurationEntry> providers_;
        private Collection<FormatConfigurationEntry> formats_;
        private Collection<CmdletConfigurationEntry> cmdlets_;

        public override string Name
        {
            get { return Resources.BizTalkMshEx_SnapIn_Name; }
        }

        public override string Vendor
        {
            get { return Resources.BizTalkMshEx_SnapIn_Vendor; }
        }

        public override string Description
        {
            get { return Resources.BizTalkMshEx_SnapIn_Description; }
        }

        public override Collection<ProviderConfigurationEntry> Providers
        {
            get
            {
                if (providers_ == null)
                {
                    providers_ = new Collection<ProviderConfigurationEntry>();
                    providers_.Add(new ProviderConfigurationEntry(
                        Resources.BizTalkMshEx_SnapIn_ProviderName
                        , typeof(BizTalkProvider)
                        , HelpFileName));
                }
                return providers_;
            }
        }

        public override Collection<FormatConfigurationEntry> Formats
        {
            get
            {
                if (formats_ == null)
                {
                    formats_ = new Collection<FormatConfigurationEntry>();
                    formats_.Add(new FormatConfigurationEntry(FormatFileName));
                    base.Formats.Add(new FormatConfigurationEntry(FormatFileName));
                    return base.Formats;
                }
                return formats_;
            }
        }

        public override Collection<CmdletConfigurationEntry> Cmdlets
        {
            get
            {
                if (cmdlets_ == null)
                {
                    cmdlets_ = new Collection<CmdletConfigurationEntry>();

                    foreach (Type type in Assembly.GetExecutingAssembly().GetTypes())
                    {
                        object[] attrs = type.GetCustomAttributes(typeof(CmdletAttribute), false);
                        if (attrs != null && attrs.Length > 0 && attrs[0] is CmdletAttribute)
                        {
                            cmdlets_.Add(
                                new CmdletConfigurationEntry(
                                      (attrs[0] as CmdletAttribute).VerbName + "-" + (attrs[0] as CmdletAttribute).NounName
                                    , type
                                    , HelpFileName));
                        }
                    }
                }

                return cmdlets_;
            }
        }

        #region Implementation

        internal static string Location
        {
            get { return System.IO.Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location); }
        }

        internal static string HelpFileName
        {
            get { return System.IO.Path.GetFileName(Assembly.GetExecutingAssembly().Location) + "-Help.xml"; }
        }

        internal static string FormatFileName
        {
            get { return System.IO.Path.GetFileNameWithoutExtension(Assembly.GetExecutingAssembly().Location) + ".BizTalk.Format.ps1xml"; }
        }

        #endregion
    }
}