﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Management.Automation;
using System.Globalization;
using BizTalkFactory.Management.Automation;
using System.Collections.ObjectModel;
using System.IO;

namespace BizTalkFactory.PowerShell.Extensions
{
    [AttributeUsage(AttributeTargets.Field | AttributeTargets.Property)]
    class ReferenceTransformationAttribute : ArgumentTransformationAttribute
    {
       /// <summary>
        /// Transforms the object provided in 'inputData' to a BtsApplication object 
        /// </summary>
        /// <param name="engineIntrinsics">Current engine intrinsics provided by the runtime</param>
        /// <param name="inputData">The input object provided to the cmdlet as parameter </param>
        /// <returns>BtsApplication object</returns>
        public override object Transform(EngineIntrinsics engineIntrinsics, object inputData)
        {
            // This method will only transform inputData when it is one of the following types:
            //  - object of type PsObject and base type of 'BtsApplication'
            //  - object type 'String'
            //  - System.String
            //  - PSObject with base object type BtsApplication.
            // All other types will cause a ParameterBindingException to be thrown.

            if (inputData is PSObject && ((PSObject)inputData).BaseObject is BtsApplication)
                return (BtsApplication)(((PSObject)inputData).BaseObject);

            else if ((inputData is PSObject) && ((inputData as PSObject).BaseObject is BtsApplication))
                   return ((inputData as PSObject).BaseObject as BtsApplication);

            else if ((inputData is PSObject) && ((inputData as PSObject).BaseObject is System.String))
                return GetBtsApplication(engineIntrinsics, ((inputData as PSObject).BaseObject as System.String));

            else if (inputData is System.String)
                return GetBtsApplication(engineIntrinsics, (inputData as System.String));
            
            throw new ParameterBindingException(String.Format(
                Resources.BizTalkMshEx_InvalidObjectType
                , (inputData is PSObject) ? (inputData as PSObject).GetType().FullName : 
                  ((inputData is String) ? (inputData as String) : inputData.GetType().FullName)
                , typeof(BtsApplication).FullName
                ));
        }

        private BtsApplication GetBtsApplication(EngineIntrinsics engineIntrinsics, string path)
        {
            ProviderInfo providerInfo = null;
            Collection<string> resolvedPaths = null;

            PSDriveInfo driveInfo = PathUtil.GetDrive(engineIntrinsics.SessionState, path, out providerInfo, out resolvedPaths);

            object[] applications = PathUtil.GetItems(driveInfo, resolvedPaths);
            System.Diagnostics.Debug.Assert(applications.Length <= 1);
            return (BtsApplication) applications[0];

            //throw new ParameterBindingException(
            //    String.Format(CultureInfo.InvariantCulture, ERROR_APPLICATION_NOT_FOUND, path)); 
        }
    }
}
