﻿using System;
using System.Collections.Generic;
using System.Runtime.InteropServices.ComTypes;

namespace BizTalkFactory.Runtime.InteropServices
{
    public sealed class ComComponent
    {
        private StdComponentCategoriesMgr manager_ = new StdComponentCategoriesMgr();

        internal ICatInformation ComCatInformation;

        private ComComponent()
        {
            ComCatInformation = (manager_ as ICatInformation);
        }

        public static IEnumerable<ComponentCategory> EnumCategories()
        {
            var components = new ComComponent();
            var pIEnumCATEGORYINFO = components
                .ComCatInformation
                .EnumCategories(
                    NativeMethods.GetUserDefaultLCID()
                );

            uint count;
            CATEGORYINFO info;

            while ((count = pIEnumCATEGORYINFO.Next((uint) 1, out info)) != 0)
                yield return ComponentCategory.FromCATEGORYINFO(info);
        }

        public static IEnumerable<Guid> EnumImplementingClasses(Guid catID)
        {
            var reqIDs = new Guid[] { };
            var catIDs = new []{catID};

            var components = new ComComponent();
            var pIEnumCLSID = components
                .ComCatInformation
                .RemoteEnumClassesOfCategories(
                    (uint)catIDs.Length, catIDs, 0, reqIDs
                );

            uint count;
            Guid classID;
            while ((count = pIEnumCLSID.Next((int)1, out classID)) != 0)
                yield return classID;
        }
    }
}
