@echo off
setlocal

set SANDCASTLE=%ProgramFiles%\Sandcastle
set STOOLS=%SANDCASTLE%\ProductionTools
set SXFORMS=%SANDCASTLE%\ProductionTransforms
set SPRES=%SANDCASTLE%\Presentation

set BUILDASSEMBLER=%STOOLS%\BuildAssembler.exe
set MREFBUILDER=%STOOLS%\MrefBuilder.exe
set XSLT=%STOOLS%\XslTransform.exe

set HHELP=%ProgramFiles%\Sandcastle\HTML Help Workshop

set HHC=%HHELP%\hhc.exe

REM Validate Parameters
REM
REM %1 assembly
REM %2 xml-comments
REM %3 output-directory
REM %4 presentation [vs2005|prototype|hana]
REM ===================

if /i '%1'=='' goto finish
if /i '%2'=='' goto finish
if /i '%3'=='' goto finish

set ASSEMBLY=%~dpnx1
set COMMENTS=%~dpnx2
set OUTPUT=%~dpn3
set PRESENTATION=Prototype

set PROJECT=%~n1

REM Proceed to Create Compiled Help File
REM ====================================

pushd %OUTPUT%

copy "%COMMENTS%" comments.xml

call "%MREFBUILDER%" "%ASSEMBLY%" /config:MRefBuilder.config /out:reflection.org
call "%XSLT%" /xsl:"%SXFORMS%\ApplyPrototypeDocModel.xsl" reflection.org /xsl:"%SXFORMS%\AddGuidFilenames.xsl" /out:reflection.xml
call "%XSLT%" /xsl:"%SXFORMS%\ReflectionToManifest.xsl" reflection.xml /out:manifest.xml

call "%SPRES%\%PRESENTATION%\copyOutput.bat"

call "%BUILDASSEMBLER%" /config:"%SPRES%\%PRESENTATION%\configuration\sandcastle.config" manifest.xml

REM Compiling HTML Help Project
REM ===========================

call "%XSLT%" /xsl:"%SXFORMS%\ReflectionToChmProject.xsl" /arg:project=%PROJECT% reflection.xml /out:Output\%PROJECT%.hhp

REM Compiling HTML Help Table of Contents
REM =====================================

if /i '%PRESENTATION%'=='Prototype' (
  call "%XSLT%" /xsl:"%SXFORMS%\createPrototypetoc.xsl" reflection.xml /out:toc.xml
) else if '%PRESENTATION%'=='vs2005' (
  call "%XSLT%" /xsl:"%SXFORMS%\createvstoc.xsl" reflection.xml /out:toc.xml
) else (
  call "%XSLT%" /xsl:"%SXFORMS%\createvstoc.xsl" reflection.xml /out:toc.xml
)

REM Compiling HTML Help Topics
REM ==========================

call "%XSLT%" /xsl:"%SXFORMS%\TocToChmContents.xsl" toc.xml /out:Output\%PROJECT%.hhc
call "%XSLT%" /xsl:"%SXFORMS%\ReflectionToChmIndex.xsl" reflection.xml /out:Output\%PROJECT%.hhk

REM Compiling HTML Help File
REM ========================


call "%HHC%" Output\%PROJECT%.hhp

REM Cleanup
REM =======

move Output\%PROJECT%.chm "%OUTPUT%\%~n1.chm" >NUL 2>&1
rmdir /s /Q Output >NUL 2>&1
rmdir /s /Q Intellisense >NUL 2>&1
del reflection.org >NUL 2>&1
del reflection.xml >NUL 2>&1
del manifest.xml >NUL 2>&1
del toc.xml >NUL 2>&1
del comments.xml >NUL 2>&1

popd

:finish
endlocal
